from .. import Provider as AddressProvider


class Provider(AddressProvider):
    cities = (
        "Warszawa",
        "Kraków",
        "Łódź",
        "Wrocław",
        "Poznań",
        "Gdańsk",
        "Szczecin",
        "Bydgoszcz",
        "Lublin",
        "Katowice",
        "Białystok",
        "Gdynia",
        "Częstochowa",
        "Radom",
        "Sosnowiec",
        "Toruń",
        "Kielce",
        "Gliwice",
        "Rzeszów",
        "Zabrze",
        "Bytom",
        "Olsztyn",
        "Bielsko-Biała",
        "Ruda Śląska",
        "Rybnik",
        "Tychy",
        "Dąbrowa Górnicza",
        "Gorzów Wielkopolski",
        "Elbląg",
        "Płock",
        "Opole",
        "Wałbrzych",
        "Zielona Góra",
        "Włocławek",
        "Tarnów",
        "Chorzów",
        "Koszalin",
        "Kalisz",
        "Legnica",
        "Grudziądz",
        "Słupsk",
        "Jaworzno",
        "Jastrzębie-Zdrój",
        "Nowy Sącz",
        "Jelenia Góra",
        "Konin",
        "Piotrków Trybunalski",
        "Siedlce",
        "Inowrocław",
        "Mysłowice",
        "Piła",
        "Lubin",
        "Ostrów Wielkopolski",
        "Ostrowiec Świętokrzyski",
        "Gniezno",
        "Stargard Szczeciński",
        "Siemianowice Śląskie",
        "Suwałki",
        "Głogów",
        "Pabianice",
        "Chełm",
        "Zamość",
        "Tomaszów Mazowiecki",
        "Leszno",
        "Przemyśl",
        "Stalowa Wola",
        "Kędzierzyn-Koźle",
        "Łomża",
        "Żory",
        "Mielec",
        "Tarnowskie Góry",
        "Tczew",
        "Bełchatów",
        "Świdnica",
        "Ełk",
        "Pruszków",
        "Będzin",
        "Biała Podlaska",
        "Zgierz",
        "Piekary Śląskie",
        "Racibórz",
        "Legionowo",
        "Ostrołęka",
        "Świętochłowice",
        "Starachowice",
        "Zawiercie",
        "Wejherowo",
        "Puławy",
        "Wodzisław Śląski",
        "Starogard Gdański",
        "Skierniewice",
        "Tarnobrzeg",
        "Skarżysko-Kamienna",
        "Radomsko",
        "Krosno",
        "Rumia",
        "Dębica",
        "Kołobrzeg",
        "Kutno",
        "Nysa",
        "Ciechanów",
        "Otwock",
        "Piaseczno",
        "Zduńska Wola",
        "Sieradz",
        "Świnoujście",
        "Żyrardów",
        "Szczecinek",
        "Świdnik",
        "Chojnice",
        "Nowa Sól",
        "Oświęcim",
        "Bolesławiec",
        "Mińsk Mazowiecki",
        "Mikołów",
        "Jarosław",
        "Sanok",
        "Knurów",
        "Malbork",
        "Żary",
        "Kwidzyn",
        "Chrzanów",
        "Sopot",
        "Sochaczew",
        "Wołomin",
        "Oleśnica",
        "Brzeg",
        "Olkusz",
        "Jasło",
        "Cieszyn",
        "Kraśnik",
        "Lębork",
        "Czechowice-Dziedzice",
        "Dzierżoniów",
        "Ostróda",
        "Police",
        "Nowy Targ",
        "Iława",
        "Czeladź",
        "Myszków",
        "Żywiec",
        "Zgorzelec",
        "Oława",
        "Bielawa",
        "Swarzędz",
        "Mława",
        "Ząbki",
        "Łuków",
        "Augustów",
        "Śrem",
        "Bochnia",
        "Luboń",
        "Giżycko",
        "Grodzisk Mazowiecki",
        "Łowicz",
        "Krotoszyn",
        "Września",
        "Turek",
        "Pruszcz Gdański",
        "Brodnica",
        "Gorlice",
        "Czerwionka-Leszczyny",
        "Kłodzko",
        "Marki",
        "Nowy Dwór Mazowiecki",
        "Kętrzyn",
        "Zakopane",
        "Wyszków",
        "Biłgoraj",
        "Żagań",
        "Bielsk Podlaski",
        "Świecie",
        "Wałcz",
        "Jarocin",
        "Pszczyna",
        "Wągrowiec",
        "Szczytno",
        "Białogard",
        "Sandomierz",
        "Bartoszyce",
        "Kluczbork",
        "Lubliniec",
        "Skawina",
        "Jawor",
        "Kościan",
        "Wieluń",
        "Kościerzyna",
        "Nowa Ruda",
        "Świebodzice",
        "Koło",
        "Piastów",
        "Goleniów",
        "Ostrów Mazowiecka",
        "Polkowice",
        "Lubartów",
        "Zambrów",
        "Płońsk",
        "Reda",
        "Łaziska Górne",
        "Środa Wielkopolska",
    )

    street_prefixes_feminine = (
        "ulica",
        "aleja",
    )

    street_prefixes_masculine = ("plac",)

    street_prefixes = street_prefixes_feminine + street_prefixes_masculine

    streets_adjective_feminine = (
        "Polna",
        "Leśna",
        "Słoneczna",
        "Krótka",
        "Szkolna",
        "Ogrodowa",
        "Lipowa",
        "Brzozowa",
        "Łąkowa",
        "Kwiatowa",
        "Sosnowa",
        "Kościelna",
        "Akacjowa",
        "Parkowa",
        "Zielona",
        "Kolejowa",
        "Sportowa",
        "Dębowa",
        "Cicha",
        "Spokojna",
        "Klonowa",
        "Spacerowa",
        "Swierkowa",
        "Kasztanowa",
        "Nowa",
        "Piaskowa",
        "Rózana",
        "Topolowa",
        "Wiśniowa",
        "Dworcowa",
        "Wiejska",
        "Graniczna",
        "Długa",
        "Wrzosowa",
        "Boczna",
        "Wąska",
        "Wierzbowa",
        "Jaśminowa",
        "Wspólna",
        "Modrzewiowa",
        "Poprzeczna",
        "Wesoła",
        "Pogodna",
        "Bukowa",
        "Sadowa",
        "Górna",
        "Jodłowa",
        "Glówna",
        "Młyńska",
        "Strażacka",
        "Jesionowa",
        "Przemysłowa",
        "Osiedlowa",
        "Wiosenna",
        "Południowa",
        "Malinowa",
        "Stawowa",
        "Reymonta",
        "Zacisze",
        "Cmentarna",
        "Okrężna",
        "Miła",
        "Jasna",
        "Wodna",
        "Zamkowa",
        "Warszawska",
        "Miodowa",
        "Krzywa",
        "Dolna",
        "Podgórna",
        "Kreta",
        "Jarzębinowa",
        "Targowa",
        "Prosta",
        "Spółdzielcza",
        "Jagodowa",
        "Działkowa",
        "Orzechowa",
        "Rzemieślnicza",
        "Rzeczna",
        "Fabryczna",
        "Tęczowa",
        "Chabrowa",
        "Poziomkowa",
        "Konwaliowa",
        "Kalinowa",
        "Północna",
        "Grunwaldzka",
        "Cisowa",
        "Nadrzeczna",
        "Pocztowa",
        "Zachodnia",
        "Dąbrowskiego",
        "Grabowa",
        "Źródlana",
        "Gajowa",
        "Mostowa",
        "Wschodnia",
        "Jaworowa",
        "Poznańska",
        "Makowa",
        "Jeziorna",
        "Piękna",
        "Czereśniowa",
        "Mała",
        "Krakowska",
        "Radosna",
        "Leszczynowa",
        "Rolna",
        "Piastowska",
        "Grzybowa",
        "Podleśna",
        "Żytnia",
        "Złota",
        "Bursztynowa",
        "Żwirowa",
        "Widokowa",
        "Kamienna",
        "Jałowcowa",
        "Morelowa",
        "Myśliwska",
        "Łączna",
        "Szpitalna",
        "Wczasowa",
        "Żurawia",
        "Fiołkowa",
        "Rolnicza",
        "Tulipanowa",
        "Dworska",
        "Letnia",
        "Liliowa",
        "Owocowa",
        "Harcerska",
        "Strzelecka",
        "Wrocławska",
        "Gdańska",
        "Turystyczna",
        "Rybacka",
        "Okrzei",
        "Krucza",
        "Jagiellońska",
        "Szeroka",
        "Młynarska",
        "Olchowa",
        "Rumiankowa",
        "Stroma",
        "Starowiejska",
        "Mazowiecka",
        "Lawendowa",
        "Robotnicza",
        "Zbożowa",
        "Mokra",
        "Towarowa",
        "Dobra",
        "Środkowa",
        "Willowa",
        "Zielna",
        "Zdrojowa",
        "Opolska",
        "Agrestowa",
        "Księżycowa",
        "Zwycięstwa",
        "Letniskowa",
        "Orla",
        "Błękitna",
        "Rubinowa",
        "Brzoskwiniowa",
        "Urocza",
        "Pomorska",
        "Jeżynowa",
        "Zaciszna",
        "Porzeczkowa",
        "Krańcowa",
        "Jesienna",
        "Klasztorna",
        "Irysowa",
        "Niecała",
        "Nadbrzeżna",
        "Wałowa",
        "Strumykowa",
        "Gołębia",
        "Torowa",
        "Cegielniana",
        "Cyprysowa",
        "Słowianska",
        "Diamentowa",
        "Częstochowska",
        "Dojazdowa",
        "Przechodnia",
        "Lubelska",
        "Borówkowa",
        "Plażowa",
        "Tartaczna",
        "Jabłoniowa",
        "Ludowa",
        "Sokola",
        "Azaliowa",
        "Szmaragdowa",
        "Lipca",
        "Jastrzębia",
        "Storczykowa",
        "Wilcza",
        "Górnicza",
        "Szafirowa",
        "Handlowa",
        "Krokusowa",
        "Składowa",
        "Widok",
        "Perłowa",
        "Skośna",
        "Wypoczynkowa",
        "Chmielna",
        "Jaskółcza",
        "Nowowiejska",
        "Piwna",
        "Śląska",
        "Zaułek",
        "Głogowa",
        "Górska",
        "Truskawkowa",
        "Kaszubska",
        "Mazurska",
        "Srebrna",
        "Bociania",
        "Ptasia",
        "Cedrowa",
        "Rycerska",
        "Żabia",
        "Toruńska",
        "Podmiejska",
        "Słonecznikowa",
        "Sowia",
        "Stolarska",
        "Szczęśliwa",
        "Lazurowa",
        "Miarki",
        "Narcyzowa",
        "Browarna",
        "Majowa",
        "Orkana",
        "Skrajna",
        "Bankowa",
        "Bydgoska",
        "Piekarska",
        "Żeglarska",
        "Turkusowa",
        "Tylna",
        "Wysoka",
        "Zakątek",
        "Morska",
        "Rataja",
        "Szewska",
        "Podwale",
        "Pałacowa",
        "Magnoliowa",
        "Ceglana",
        "Wiklinowa",
        "Zakole",
        "Borowa",
        "Kolorowa",
        "Lisia",
        "Lotnicza",
        "Sarnia",
        "Wiązowa",
        "Kolonia",
        "Królewska",
        "Promienna",
        "Daleka",
        "Wiatraczna",
        "Kaliska",
        "Łanowa",
        "Średnia",
        "Wiślana",
        "Koralowa",
        "Sybiraków",
        "Kowalska",
        "Morcinka",
        "Odrzańska",
        "Okulickiego",
        "Zapolskiej",
        "Łabędzia",
        "Bałtycka",
        "Lwowska",
        "Rajska",
        "Pszenna",
        "Ciasna",
        "Hutnicza",
        "Kielecka",
    )

    streets_universal = (
        "Stycznia",
        "Maja",
        "Listopada",
        "Rynek",
        "Kościuszki",
        "Mickiewicza",
        "Sienkiewicza",
        "Słowackiego",
        "Konopnickiej",
        "Kopernika",
        "Jana Pawła II",
        "Żeromskiego",
        "Wojska Polskiego",
        "Wolności",
        "Prusa",
        "Sikorskiego",
        "Chopina",
        "Piłsudskiego",
        "Kochanowskiego",
        "Armii Krajowej",
        "Witosa",
        "Reja",
        "Partyzantów",
        "Kilińskiego",
        "Moniuszki",
        "Orzeszkowej",
        "Staszica",
        "Bolesława Chrobrego",
        "Wyszyńskiego",
        "Matejki",
        "Norwida",
        "Asnyka",
        "Paderewskiego",
        "Wyspiańskiego",
        "Broniewskiego",
        "Tuwima",
        "Bema",
        "Traugutta",
        "Jadwigi",
        "Wyzwolenia",
        "Krasickiego",
        "Kazimierza Wielkiego",
        "Mieszka I",
        "Głowackiego",
        "Władysława Jagiełły",
        "Pułaskiego",
        "Stefana Batorego",
        "Kołłątaja",
        "Kraszewskiego",
        "Władysława Łokietka",
        "Żwirki i Wigury",
        "Niepodległości",
        "Poniatowskiego",
        "Korczaka",
        "Narutowicza",
        "Świerczewskiego",
        "Kasprowicza",
        "Jana III Sobieskiego",
        "Powstańców Śląskich",
        "Powstańców Wielkopolskich",
        "Fredry",
        "Andersa",
        "Baczyńskiego",
        "Batalionów Chłopskich",
        "Dąbrowskiej",
        "Skłodowskiej-Curie",
        "Gałczyńskiego",
        "Krasińskiego",
        "Szymanowskiego",
        "Czarnieckiego",
        "Nałkowskiej",
        "Wybickiego",
        "Szarych Szeregów",
        "Słowicza",
        "Drzymały",
        "Waryńskiego",
        "Hallera",
        "Plater",
        "Popiełuszki",
        "Chełmońskiego",
        "Daszyńskiego",
        "Kossaka",
        "Skargi",
        "Staffa",
        "Tysiąclecia",
        "Brzechwy",
        "Kusocińskiego",
        "Długosza",
        "Kosynierów",
        "Wieniawskiego",
        "Powstańców",
        "Sucharskiego",
        "Bolesława Krzywoustego",
        "Konarskiego",
        "Konstytucji 3 Maja",
        "Miłosza",
        "Malczewskiego",
        "Jana",
        "Maczka",
        "Sawickiej",
        "Ściegiennego",
        "Grottgera",
        "Jana Sobieskiego",
        "Rejtana",
        "Wróblewskiego",
        "Kruczkowskiego",
        "Lelewela",
        "Makuszyńskiego",
        "Solidarności",
        "Wojciecha",
        "Korfantego",
        "Floriana",
    )

    streets = streets_adjective_feminine + streets_universal

    regions = (
        "Dolnośląskie",
        "Kujawsko - pomorskie",
        "Lubelskie",
        "Lubuskie",
        "Łódzkie",
        "Małopolskie",
        "Mazowieckie",
        "Opolskie",
        "Podkarpackie",
        "Podlaskie",
        "Pomorskie",
        "Śląskie",
        "Świętokrzyskie",
        "Warmińsko - mazurskie",
        "Wielkopolskie",
        "Zachodniopomorskie",
    )

    building_number_formats = ("##", "###", "##/##")
    postcode_formats = ("##-###",)
    street_address_formats = (
        "{{street_prefix_feminine}} {{street_name_adjective_feminine}} {{building_number}}",
        "{{street_prefix_feminine}} {{street_name_universal}} {{building_number}}",
        "{{street_prefix_masculine}} {{street_name_universal}} {{building_number}}",
        "{{street_prefix_feminine_short}} {{street_name_adjective_feminine}} {{building_number}}",
        "{{street_prefix_feminine_short}} {{street_name_universal}} {{building_number}}",
        "{{street_prefix_masculine_short}} {{street_name_universal}} {{building_number}}",
    )
    address_formats = ("{{street_address}}\n{{postcode}} {{city}}",)

    def street_prefix(self) -> str:
        """
        Randomly returns a street prefix
        :example: 'aleja'
        """
        return self.random_element(self.street_prefixes)

    def street_prefix_feminine(self) -> str:
        """
        Randomly returns a feminine street prefix
        :example: 'aleja'
        """
        return self.random_element(self.street_prefixes_feminine)

    def street_prefix_masculine(self) -> str:
        """
        Randomly returns a masculine street prefix
        :example: 'plac'
        """
        return self.random_element(self.street_prefixes_masculine)

    def street_prefix_short(self) -> str:
        """
        Randomly returns an abbreviation of the street prefix.
        :example: 'al.'
        """
        return self.random_element(self.street_prefixes)[:2] + "."  # type: ignore

    def street_prefix_feminine_short(self) -> str:
        """
        Randomly returns an abbreviation of the feminine street prefix.
        :example: 'al.'
        """
        return self.random_element(self.street_prefixes_feminine)[:2] + "."  # type: ignore

    def street_prefix_masculine_short(self) -> str:
        """
        Randomly returns an abbreviation of the masculine street prefix.
        :example: 'pl.'
        """
        return self.random_element(self.street_prefixes_masculine)[:2] + "."  # type: ignore

    def street_name(self) -> str:
        """
        Randomly returns a street name
        :example: 'Wróblewskiego'
        """
        return self.random_element(self.streets)

    def street_name_adjective_feminine(self) -> str:
        """
        Randomly returns an adjective feminine street name
        :example: 'Zielona'
        """
        return self.random_element(self.streets_adjective_feminine)

    def street_name_universal(self) -> str:
        """
        Randomly returns a universal street name
        :example: 'Wróblewskiego'
        """
        return self.random_element(self.streets_universal)

    def city(self) -> str:
        """
        Randomly returns a city name
        :example: 'Konin'
        """
        return self.random_element(self.cities)

    def administrative_unit(self) -> str:
        """
        :example: 'Wielkopolskie'
        """
        return self.random_element(self.regions)

    def postcode(self) -> str:
        """
        :example: '62-200'
        """
        return "%02d-%03d" % (self.generator.random.randint(1, 99), self.generator.random.randint(1, 999))

    def zipcode(self) -> str:
        """
        :example: '62-200'
        """
        return self.postcode()

    def postalcode(self) -> str:
        """
        :example: '62-200'
        """
        return self.postcode()

    region = administrative_unit



from .. import Provider as BarcodeProvider


class Provider(BarcodeProvider):
    """Implement barcode provider for ``ja_JP`` locale.

    Japanese local EAN barcodes are called JAN-codes.

    Sources:

    - https://gs1.org/standards/id-keys/company-prefix
    - https://www.dsri.jp/jan/about_jan.html

    .. |JaJpProvider.localized_ean| replace::
       :meth:`JaJpProvider.localized_ean() <faker.providers.barcode.ja_JP.Provider.localized_ean>`

    .. |JaJpProvider.localized_ean8| replace::
       :meth:`JaJpProvider.localized_ean8() <faker.providers.barcode.ja_JP.Provider.localized_ean8>`

    .. |JaJpProvider.localized_ean13| replace::
       :meth:`JaJpProvider.localized_ean13() <faker.providers.barcode.ja_JP.Provider.localized_ean13>`
    """

    local_prefixes = (4, 5), (4, 9)

    def jan(self, length: int = 13) -> str:
        """Generate a JAN barcode of the specified ``length``.

        This method is an alias for |JaJpProvider.localized_ean|.

        :sample:
        :sample: length=8
        :sample: length=13
        """
        return self.localized_ean(length)

    def jan8(self) -> str:
        """Generate a 8 digit JAN barcode.

        This method is an alias for |JaJpProvider.localized_ean8|.
        """
        return self.localized_ean8()

    def jan13(self) -> str:
        """Generate a 13 digit JAN barcode.

        This method is an alias for |JaJpProvider.localized_ean13|.
        """
        return self.localized_ean13()



from .. import Provider as AddressProvider


class Provider(AddressProvider):
    city_suffixes = ("市", "县")
    city_formats = ("{{city_name}}{{city_suffix}}", "{{first_name}}{{city_suffix}}")

    district_formats = ("{{district}}区",)

    building_number_formats = ("?座",)
    postcode_formats = ("%#####",)

    street_suffixes = ("街", "路")
    street_name_formats = (
        "{{city_name}}{{street_suffix}}",
        "{{last_name}}{{street_suffix}}",
    )
    street_address_formats = ("{{street_name}}{{building_number}}",)

    address_formats = ("{{province}}{{city}}{{district}}{{street_address}} {{postcode}}",)

    provinces = (
        "北京市",
        "上海市",
        "天津市",
        "重庆市",
        "内蒙古自治区",
        "山西省",
        "河北省",
        "吉林省",
        "江苏省",
        "辽宁省",
        "黑龙江省",
        "安徽省",
        "山东省",
        "浙江省",
        "江西省",
        "福建省",
        "湖南省",
        "湖北省",
        "河南省",
        "广东省",
        "广西壮族自治区",
        "贵州省",
        "海南省",
        "四川省",
        "云南省",
        "陕西省",
        "甘肃省",
        "宁夏回族自治区",
        "青海省",
        "新疆维吾尔自治区",
        "西藏自治区",
        "台湾省",
        "香港特别行政区",
        "澳门特别行政区",
    )
    districts = (
        "西夏",
        "永川",
        "秀英",
        "高港",
        "清城",
        "兴山",
        "锡山",
        "清河",
        "龙潭",
        "华龙",
        "海陵",
        "滨城",
        "东丽",
        "高坪",
        "沙湾",
        "平山",
        "城北",
        "海港",
        "沙市",
        "双滦",
        "长寿",
        "山亭",
        "南湖",
        "浔阳",
        "南长",
        "友好",
        "安次",
        "翔安",
        "沈河",
        "魏都",
        "西峰",
        "萧山",
        "金平",
        "沈北新",
        "孝南",
        "上街",
        "城东",
        "牧野",
        "大东",
        "白云",
        "花溪",
        "吉区",
        "新城",
        "怀柔",
        "六枝特",
        "涪城",
        "清浦",
        "南溪",
        "淄川",
        "高明",
        "东城",
        "崇文",
        "朝阳",
        "大兴",
        "房山",
        "门头沟",
        "黄浦",
        "徐汇",
        "静安",
        "普陀",
        "闵行",
        "和平",
        "蓟州",
        "永川",
        "长寿",
        "璧山",
        "合川",
        "梁平",
        "丰都",
        "江北",
    )
    cities = (
        "北京",
        "上海",
        "天津",
        "重庆",
        "哈尔滨",
        "长春",
        "沈阳",
        "呼和浩特",
        "石家庄",
        "乌鲁木齐",
        "兰州",
        "西宁",
        "西安",
        "银川",
        "郑州",
        "济南",
        "太原",
        "合肥",
        "武汉",
        "长沙",
        "南京",
        "成都",
        "贵阳",
        "昆明",
        "南宁",
        "拉萨",
        "杭州",
        "南昌",
        "广州",
        "福州",
        "台北",
        "海口",
        "香港",
        "澳门",
        "通辽",
        "兴安盟",
        "太原",
        "辛集",
        "邯郸",
        "沈阳",
        "辽阳",
        "兴城",
        "北镇",
        "阜新",
        "哈尔滨",
        "齐齐哈尔",
        "淮安",
        "张家港",
        "海门",
        "六安",
        "巢湖",
        "马鞍山",
        "永安",
        "宁德",
        "嘉禾",
        "荆门",
        "潜江",
        "大冶",
        "宜都",
        "佛山",
        "深圳",
        "潮州",
        "惠州",
        "汕尾",
        "东莞",
        "梧州",
        "柳州",
        "合山",
        "六盘水",
        "关岭",
    )
    countries = (
        "阿富汗",
        "阿拉斯加",
        "阿尔巴尼亚",
        "阿尔及利亚",
        "安道尔",
        "安哥拉",
        "安圭拉岛英",
        "安提瓜和巴布达",
        "阿根廷",
        "亚美尼亚",
        "阿鲁巴岛",
        "阿森松",
        "澳大利亚",
        "奥地利",
        "阿塞拜疆",
        "巴林",
        "孟加拉国",
        "巴巴多斯",
        "白俄罗斯",
        "比利时",
        "伯利兹",
        "贝宁",
        "百慕大群岛",
        "不丹",
        "玻利维亚",
        "波斯尼亚和黑塞哥维那",
        "博茨瓦纳",
        "巴西",
        "保加利亚",
        "布基纳法索",
        "布隆迪",
        "喀麦隆",
        "加拿大",
        "加那利群岛",
        "佛得角",
        "开曼群岛",
        "中非",
        "乍得",
        "智利",
        "圣诞岛",
        "科科斯岛",
        "哥伦比亚",
        "巴哈马国",
        "多米尼克国",
        "科摩罗",
        "刚果",
        "科克群岛",
        "哥斯达黎加",
        "克罗地亚",
        "古巴",
        "塞浦路斯",
        "捷克",
        "丹麦",
        "迪戈加西亚岛",
        "吉布提",
        "多米尼加共和国",
        "厄瓜多尔",
        "埃及",
        "萨尔瓦多",
        "赤道几内亚",
        "厄立特里亚",
        "爱沙尼亚",
        "埃塞俄比亚",
        "福克兰群岛",
        "法罗群岛",
        "斐济",
        "芬兰",
        "法国",
        "法属圭亚那",
        "法属波里尼西亚",
        "加蓬",
        "冈比亚",
        "格鲁吉亚",
        "德国",
        "加纳",
        "直布罗陀",
        "希腊",
        "格陵兰岛",
        "格林纳达",
        "瓜德罗普岛",
        "关岛",
        "危地马拉",
        "几内亚",
        "几内亚比绍",
        "圭亚那",
        "海地",
        "夏威夷",
        "洪都拉斯",
        "匈牙利",
        "冰岛",
        "印度",
        "印度尼西亚",
        "伊郎",
        "伊拉克",
        "爱尔兰",
        "以色列",
        "意大利",
        "科特迪瓦",
        "牙买加",
        "日本",
        "约旦",
        "柬埔塞",
        "哈萨克斯坦",
        "肯尼亚",
        "基里巴斯",
        "朝鲜",
        "韩国",
        "科威特",
        "吉尔吉斯斯坦",
        "老挝",
        "拉脱维亚",
        "黎巴嫩",
        "莱索托",
        "利比里亚",
        "利比亚",
        "列支敦士登",
        "立陶宛",
        "卢森堡",
        "北马其顿",
        "马达加斯加",
        "马拉维",
        "马来西亚",
        "马尔代夫",
        "马里",
        "马耳他",
        "马里亚纳群岛",
        "马绍尔群岛",
        "马提尼克",
        "毛里塔尼亚",
        "毛里求斯",
        "马约特岛",
        "墨西哥",
        "密克罗尼西亚",
        "中途岛",
        "摩尔多瓦",
        "摩纳哥",
        "蒙古",
        "蒙特塞拉特岛",
        "摩洛哥",
        "莫桑比克",
        "缅甸",
        "纳米比亚",
        "瑙鲁",
        "尼泊尔",
        "荷兰",
        "荷属安的列斯群岛",
        "新喀里多尼亚群岛",
        "新西兰",
        "尼加拉瓜",
        "尼日尔",
        "尼日利亚",
        "纽埃岛",
        "诺福克岛",
        "挪威",
        "阿曼",
        "帕劳",
        "巴拿马",
        "巴布亚新几内亚",
        "巴拉圭",
        "秘鲁",
        "菲律宾",
        "波兰",
        "葡萄牙",
        "巴基斯坦",
        "波多黎各",
        "卡塔尔",
        "留尼汪岛",
        "罗马尼亚",
        "俄罗斯",
        "卢旺达",
        "东萨摩亚",
        "西萨摩亚",
        "圣马力诺",
        "圣皮埃尔岛及密克隆岛",
        "圣多美和普林西比",
        "沙特阿拉伯",
        "塞内加尔",
        "塞舌尔",
        "新加坡",
        "斯洛伐克",
        "斯洛文尼亚",
        "所罗门群岛",
        "索马里",
        "南非",
        "西班牙",
        "斯里兰卡",
        "圣克里斯托弗和尼维斯",
        "圣赫勒拿",
        "圣卢西亚",
        "圣文森特岛",
        "苏丹",
        "苏里南",
        "斯威士兰",
        "瑞典",
        "瑞士",
        "叙利亚",
        "塔吉克斯坦",
        "坦桑尼亚",
        "泰国",
        "阿拉伯联合酋长国",
        "多哥",
        "托克劳群岛",
        "汤加",
        "特立尼达和多巴哥",
        "突尼斯",
        "土耳其",
        "土库曼斯坦",
        "特克斯和凯科斯群岛",
        "图瓦卢",
        "美国",
        "乌干达",
        "乌克兰",
        "英国",
        "乌拉圭",
        "乌兹别克斯坦",
        "瓦努阿图",
        "梵蒂冈",
        "委内瑞拉",
        "越南",
        "维尔京群岛",
        "维尔京群岛和圣罗克伊",
        "威克岛",
        "瓦里斯和富士那群岛",
        "西撒哈拉",
        "也门",
        "南斯拉夫",
        "扎伊尔",
        "赞比亚",
        "桑给巴尔",
        "津巴布韦",
        "中华人民共和国",
        "中国",
    )

    def building_number(self) -> str:
        return self.lexify(self.random_element(self.building_number_formats))

    def city_name(self) -> str:
        return self.random_element(self.cities)

    def administrative_unit(self) -> str:
        return self.random_element(self.provinces)

    province = administrative_unit

    def district(self) -> str:
        return self.random_element(self.districts)



from .. import Provider as PhoneNumberProvider


class Provider(PhoneNumberProvider):
    # Source: https://en.wikipedia.org/wiki/Telephone_numbers_in_the_United_Arab_Emirates

    cellphone_formats = (
        "{{area_code}} {{cellphone_provider_code}} ### ####",
        "{{area_code}}{{cellphone_provider_code}}#######",
        "0{{cellphone_provider_code}} ### ####",
        "0{{cellphone_provider_code}}#######",
    )

    telephone_formats = (
        "{{area_code}} {{telephone_provider_code}} ### ####",
        "{{area_code}}{{telephone_provider_code}}#######",
        "0{{telephone_provider_code}} ### ####",
        "0{{telephone_provider_code}}#######",
    )

    toll_formats = (
        "200####",
        "600######",
        "800###",
        "800####",
        "800#####",
        "800######",
        "800#######",
    )

    services_phones_formats = (
        "999",
        "901",
        "998",
        "997",
        "996",
        "991",
        "922",
    )

    formats = cellphone_formats + telephone_formats + services_phones_formats + toll_formats

    def cellphone_provider_code(self) -> str:
        return self.random_element(
            [
                "50",
                "52",
                "54",
                "55",
                "56",
                "58",
            ]
        )

    def telephone_provider_code(self) -> str:
        return self.random_element(
            [
                "1",
                "2",
                "3",
                "4",
                "6",
                "7",
                "9",
            ]
        )

    def area_code(self) -> str:
        return self.random_element(
            [
                "00971",
                "+971",
            ]
        )

    def cellphone_number(self) -> str:
        pattern: str = self.random_element(self.cellphone_formats)
        return self.numerify(self.generator.parse(pattern))

    def telephone_number(self) -> str:
        pattern: str = self.random_element(self.telephone_formats)
        return self.numerify(self.generator.parse(pattern))

    def service_phone_number(self) -> str:
        pattern: str = self.random_element(self.services_phones_formats)
        return self.numerify(self.generator.parse(pattern))

    def toll_number(self) -> str:
        pattern: str = self.random_element(self.toll_formats)
        return self.numerify(self.generator.parse(pattern))

    def phone_number(self) -> str:
        pattern: str = self.random_element(self.formats)
        return self.numerify(self.generator.parse(pattern))



from .. import Provider as BankProvider


class Provider(BankProvider):
    """Implement bank provider for ``el_GR`` locale."""

    bban_format = "#######################"
    country_code = "GR"

    # Major GR banks (with a head office in Greece)
    # Source:
    # - https://www.bankofgreece.gr/en/main-tasks/supervision/supervised-institutions
    # Last verified: January 2026
    banks = (
        "Aegean Baltic Bank",
        "Alpha Bank",
        "Credia Bank",
        "Eurobank",
        "Optima Bank",
        "SNAPPI",
        "Vivabank",
        "Εθνική Τράπεζα",
        "Συνεταιριστική Τράπεζα Θεσσαλίας",
        "Συνεταιριστική Τράπεζα Καρδίτσας",
        "Συνεταιριστική Τράπεζα Χανίων",
        "Τράπεζα Ηπείρου",
        "Τράπεζα Πειραιώς",
    )



from typing import Dict

from .. import Provider as LoremProvider


class Provider(LoremProvider):
    """Implement lorem provider for ``it_IT`` locale.

    Word list is based on the source(s) below, and some words have been removed
    to make the word list appropriate for public testing.

    Sources:

    - https://github.com/napolux/paroleitaliane
    """

    word_list: tuple = (
        "a",
        "abbandonare",
        "abbastanza",
        "abitare",
        "abito",
        "accadere",
        "accanto",
        "accendere",
        "accettare",
        "accogliere",
        "accompagnare",
        "accordo",
        "accorgersi",
        "acqua",
        "addirittura",
        "addosso",
        "adesso",
        "affare",
        "affatto",
        "affermare",
        "affrontare",
        "aggiungere",
        "ah",
        "aiutare",
        "aiuto",
        "albergo",
        "albero",
        "alcuno",
        "allontanare",
        "allora",
        "almeno",
        "alto",
        "altro",
        "alzare",
        "amare",
        "ambiente",
        "americano",
        "amico",
        "ammazzare",
        "ammettere",
        "amore",
        "ampio",
        "anche",
        "ancora",
        "andare",
        "angolo",
        "anima",
        "animale",
        "animo",
        "anno",
        "annunciare",
        "antico",
        "anzi",
        "apparire",
        "appartenere",
        "appena",
        "appoggiare",
        "appunto",
        "aprire",
        "argomento",
        "aria",
        "arma",
        "armare",
        "arrestare",
        "arrivare",
        "arte",
        "articolo",
        "ascoltare",
        "aspettare",
        "aspetto",
        "assai",
        "assicurare",
        "assistere",
        "assoluto",
        "assumere",
        "attaccare",
        "atteggiamento",
        "attendere",
        "attento",
        "attenzione",
        "attesa",
        "attimo",
        "attività",
        "atto",
        "attore",
        "attorno",
        "attraversare",
        "attuale",
        "aumentare",
        "automobile",
        "autore",
        "autorità",
        "avanti",
        "avanzare",
        "avere",
        "avvenire",
        "avvertire",
        "avvicinare",
        "avvocato",
        "azione",
        "azzurro",
        "baciare",
        "badare",
        "bagno",
        "bambina",
        "bambino",
        "base",
        "basso",
        "bastare",
        "battaglia",
        "battere",
        "bellezza",
        "bello",
        "bene",
        "bere",
        "bestia",
        "bianco",
        "biondo",
        "bisognare",
        "bisogno",
        "bocca",
        "bosco",
        "braccio",
        "bravo",
        "breve",
        "bruciare",
        "brutto",
        "buio",
        "buono",
        "buttare",
        "cadere",
        "caffè",
        "calcio",
        "caldo",
        "cambiare",
        "camera",
        "camminare",
        "campagna",
        "campo",
        "cane",
        "cantare",
        "capace",
        "capello",
        "capire",
        "capitare",
        "capo",
        "carattere",
        "caratteristico",
        "carne",
        "caro",
        "carta",
        "casa",
        "caso",
        "cattivo",
        "cattolico",
        "causa",
        "cavallo",
        "celebrare",
        "centrale",
        "centro",
        "cercare",
        "certamente",
        "certo",
        "che",
        "chi",
        "chiamare",
        "chiaro",
        "chiave",
        "chiedere",
        "chiesa",
        "chilometro",
        "chissà",
        "chiudere",
        "ci",
        "ciascuno",
        "cielo",
        "cioè",
        "circa",
        "cittadino",
        "città",
        "civile",
        "civiltà",
        "ciò",
        "classe",
        "collina",
        "collo",
        "colore",
        "coloro",
        "colpa",
        "colpire",
        "colpo",
        "come",
        "cominciare",
        "commercio",
        "commissione",
        "comodo",
        "compagnia",
        "compagno",
        "compiere",
        "completamente",
        "comporre",
        "comprare",
        "comprendere",
        "comune",
        "comunicazione",
        "comunque",
        "con",
        "concedere",
        "concetto",
        "concludere",
        "condizione",
        "condurre",
        "confessare",
        "confronto",
        "congresso",
        "conoscenza",
        "conoscere",
        "conseguenza",
        "consentire",
        "conservare",
        "considerare",
        "consiglio",
        "contadino",
        "contare",
        "contatto",
        "contenere",
        "contento",
        "continuare",
        "continuo",
        "conto",
        "contrario",
        "contro",
        "controllo",
        "convincere",
        "coprire",
        "coraggio",
        "corpo",
        "corrente",
        "correre",
        "corsa",
        "corso",
        "cortile",
        "cosa",
        "coscienza",
        "costa",
        "costituire",
        "costringere",
        "costruire",
        "costruzione",
        "creare",
        "credere",
        "crescere",
        "crisi",
        "cristiano",
        "croce",
        "cucina",
        "cui",
        "cultura",
        "cuore",
        "cura",
        "da",
        "dare",
        "davanti",
        "davvero",
        "decidere",
        "decisione",
        "dedicare",
        "denaro",
        "dente",
        "dentro",
        "descrivere",
        "desiderare",
        "desiderio",
        "destino",
        "destro",
        "determinare",
        "di",
        "dichiarare",
        "dietro",
        "difendere",
        "difesa",
        "differenza",
        "difficile",
        "difficoltà",
        "diffondere",
        "dimenticare",
        "dimostrare",
        "dinanzi",
        "dio",
        "dipendere",
        "dire",
        "diretto",
        "direttore",
        "direzione",
        "dirigere",
        "diritto",
        "discorso",
        "discutere",
        "disporre",
        "disposizione",
        "distanza",
        "distinguere",
        "distruggere",
        "dito",
        "divenire",
        "diventare",
        "diverso",
        "divertire",
        "dividere",
        "dolce",
        "dolore",
        "domanda",
        "domandare",
        "domani",
        "domenica",
        "don",
        "donna",
        "dopo",
        "dormire",
        "dottore",
        "dove",
        "dovere",
        "dubbio",
        "dunque",
        "durante",
        "durare",
        "duro",
        "e",
        "eccellenza",
        "eccetera",
        "ecco",
        "economico",
        "effetto",
        "egli",
        "eh",
        "elemento",
        "elettrico",
        "elevare",
        "energia",
        "enorme",
        "entrare",
        "entro",
        "epoca",
        "eppure",
        "erba",
        "errore",
        "esame",
        "escludere",
        "esempio",
        "esercito",
        "esistere",
        "esperienza",
        "esporre",
        "espressione",
        "esprimere",
        "essa",
        "essere",
        "esso",
        "estate",
        "estendere",
        "estero",
        "estremo",
        "età",
        "europeo",
        "evitare",
        "fabbrica",
        "faccia",
        "facile",
        "fame",
        "famiglia",
        "famoso",
        "fantasia",
        "fatica",
        "fatto",
        "favore",
        "fede",
        "felice",
        "fenomeno",
        "ferire",
        "fermare",
        "fermo",
        "ferro",
        "festa",
        "fianco",
        "fiducia",
        "figlia",
        "figlio",
        "figura",
        "figurare",
        "film",
        "filo",
        "finalmente",
        "finché",
        "fine",
        "finestra",
        "finire",
        "fino",
        "fiore",
        "fissare",
        "fiume",
        "foglia",
        "folla",
        "fondare",
        "fondo",
        "forma",
        "formare",
        "fornire",
        "forse",
        "forte",
        "fortuna",
        "forza",
        "fra",
        "francese",
        "frase",
        "fratello",
        "freddo",
        "fresco",
        "fretta",
        "fronte",
        "frutto",
        "fuggire",
        "fumare",
        "funzione",
        "fuoco",
        "fuori",
        "futuro",
        "gamba",
        "gatto",
        "generale",
        "genere",
        "gente",
        "gesto",
        "gettare",
        "giallo",
        "giardino",
        "giocare",
        "gioco",
        "gioia",
        "giornale",
        "giornata",
        "giorno",
        "giovane",
        "giovanotto",
        "girare",
        "giro",
        "giudicare",
        "giudizio",
        "giugno",
        "giungere",
        "giustizia",
        "giusto",
        "già",
        "giù",
        "godere",
        "governo",
        "grado",
        "grande",
        "grave",
        "grazia",
        "grazie",
        "greco",
        "gridare",
        "grigio",
        "grosso",
        "gruppo",
        "guardare",
        "guardia",
        "guerra",
        "guidare",
        "gusto",
        "idea",
        "ieri",
        "il",
        "immaginare",
        "immagine",
        "imparare",
        "impedire",
        "imporre",
        "importante",
        "importanza",
        "importare",
        "impossibile",
        "impressione",
        "improvviso",
        "in",
        "incontrare",
        "indicare",
        "indietro",
        "industria",
        "industriale",
        "infatti",
        "infine",
        "inglese",
        "iniziare",
        "inizio",
        "innamorare",
        "inoltre",
        "insegnare",
        "insieme",
        "insistere",
        "insomma",
        "intanto",
        "intendere",
        "intenzione",
        "interessante",
        "interessare",
        "interesse",
        "internazionale",
        "interno",
        "intero",
        "intorno",
        "inutile",
        "invece",
        "inverno",
        "invitare",
        "io",
        "isola",
        "istante",
        "istituto",
        "italiano",
        "labbro",
        "lago",
        "lanciare",
        "largo",
        "lasciare",
        "latino",
        "lato",
        "latte",
        "lavorare",
        "lavoro",
        "legare",
        "legge",
        "leggere",
        "leggero",
        "lei",
        "lettera",
        "letto",
        "levare",
        "li",
        "liberare",
        "libero",
        "libertà",
        "libro",
        "limitare",
        "limite",
        "linea",
        "lingua",
        "lira",
        "lo",
        "lontano",
        "loro",
        "lotta",
        "luce",
        "lui",
        "luna",
        "lungo",
        "luogo",
        "là",
        "lì",
        "ma",
        "macchina",
        "madre",
        "maestro",
        "magari",
        "maggio",
        "maggiore",
        "malattia",
        "male",
        "mamma",
        "mancare",
        "mandare",
        "mangiare",
        "maniera",
        "mano",
        "mantenere",
        "mare",
        "marito",
        "massa",
        "massimo",
        "materia",
        "matrimonio",
        "mattina",
        "mattino",
        "medesimo",
        "medico",
        "medio",
        "meglio",
        "memoria",
        "meno",
        "mente",
        "mentre",
        "mercato",
        "meritare",
        "merito",
        "mese",
        "messa",
        "mestiere",
        "metro",
        "mettere",
        "metà",
        "mezzo",
        "mi",
        "migliore",
        "milione",
        "militare",
        "minimo",
        "ministro",
        "minore",
        "minuto",
        "mio",
        "misura",
        "moderno",
        "modo",
        "moglie",
        "molto",
        "momento",
        "mondo",
        "montagna",
        "monte",
        "morale",
        "morire",
        "morte",
        "mostrare",
        "motivo",
        "movimento",
        "muovere",
        "muro",
        "musica",
        "nascere",
        "nascondere",
        "natura",
        "naturale",
        "naturalmente",
        "nave",
        "nazionale",
        "nazione",
        "ne",
        "neanche",
        "necessario",
        "necessità",
        "nemico",
        "nemmeno",
        "neppure",
        "nero",
        "nessuno",
        "niente",
        "no",
        "nobile",
        "noi",
        "nome",
        "non",
        "nord",
        "normale",
        "nostro",
        "notare",
        "notevole",
        "notizia",
        "noto",
        "notte",
        "nudo",
        "nulla",
        "numero",
        "numeroso",
        "nuovo",
        "né",
        "o",
        "occasione",
        "occhio",
        "occorrere",
        "odore",
        "offendere",
        "offrire",
        "oggetto",
        "oggi",
        "ogni",
        "ognuno",
        "oh",
        "oltre",
        "ombra",
        "onore",
        "opera",
        "operaio",
        "operazione",
        "opinione",
        "opporre",
        "oppure",
        "ora",
        "oramai",
        "ordinare",
        "ordine",
        "orecchio",
        "organizzare",
        "origine",
        "oro",
        "ospedale",
        "osservare",
        "ottenere",
        "pace",
        "padre",
        "padrone",
        "paese",
        "pagare",
        "pagina",
        "palazzo",
        "pane",
        "papà",
        "parecchio",
        "parere",
        "parete",
        "parlare",
        "parola",
        "parte",
        "partecipare",
        "particolare",
        "partire",
        "partito",
        "passare",
        "passato",
        "passione",
        "passo",
        "patria",
        "paura",
        "pazzo",
        "peccato",
        "peggio",
        "pelle",
        "pena",
        "pensare",
        "pensiero",
        "per",
        "perché",
        "perciò",
        "perdere",
        "perfetto",
        "perfino",
        "pericolo",
        "pericoloso",
        "periodo",
        "permettere",
        "persona",
        "personaggio",
        "personale",
        "però",
        "pesare",
        "peso",
        "pezzo",
        "piacere",
        "piangere",
        "piano",
        "pianta",
        "piantare",
        "pianura",
        "piazza",
        "piccolo",
        "piede",
        "pieno",
        "pietra",
        "pietà",
        "piuttosto",
        "più",
        "poco",
        "poesia",
        "poeta",
        "poiché",
        "politica",
        "politico",
        "polizia",
        "pomeriggio",
        "ponte",
        "popolazione",
        "popolo",
        "porre",
        "porta",
        "portare",
        "porto",
        "posare",
        "posizione",
        "possedere",
        "possibile",
        "possibilità",
        "posto",
        "potenza",
        "potere",
        "povero",
        "pranzo",
        "prato",
        "preciso",
        "preferire",
        "pregare",
        "prendere",
        "preoccupare",
        "preparare",
        "presentare",
        "presente",
        "presenza",
        "presidente",
        "presso",
        "presto",
        "prevedere",
        "prezzo",
        "prima",
        "primo",
        "principale",
        "principe",
        "principio",
        "privato",
        "probabilmente",
        "problema",
        "procedere",
        "processo",
        "prodotto",
        "produrre",
        "produzione",
        "professore",
        "profondo",
        "programma",
        "promettere",
        "pronto",
        "proporre",
        "proposito",
        "proposta",
        "proprio",
        "prossimo",
        "prova",
        "provare",
        "provincia",
        "provocare",
        "provvedere",
        "pubblicare",
        "pubblico",
        "punta",
        "punto",
        "pure",
        "puro",
        "qua",
        "quadro",
        "qualche",
        "qualcosa",
        "qualcuno",
        "quale",
        "qualità",
        "qualsiasi",
        "qualunque",
        "quanto",
        "quarto",
        "quasi",
        "quello",
        "questione",
        "questo",
        "qui",
        "quindi",
        "raccogliere",
        "raccontare",
        "ragazza",
        "ragazzo",
        "raggiungere",
        "ragione",
        "rapido",
        "rapporto",
        "rappresentare",
        "reale",
        "realtà",
        "recare",
        "recente",
        "regione",
        "regno",
        "relazione",
        "religioso",
        "rendere",
        "repubblica",
        "resistere",
        "restare",
        "resto",
        "ricchezza",
        "ricco",
        "ricerca",
        "ricevere",
        "richiedere",
        "riconoscere",
        "ricordare",
        "ricordo",
        "ridere",
        "ridurre",
        "riempire",
        "rientrare",
        "riferire",
        "rifiutare",
        "riguardare",
        "rimanere",
        "rimettere",
        "ringraziare",
        "ripetere",
        "riportare",
        "riprendere",
        "risolvere",
        "rispetto",
        "rispondere",
        "risposta",
        "risultare",
        "risultato",
        "ritenere",
        "ritornare",
        "ritorno",
        "ritrovare",
        "riunire",
        "riuscire",
        "riva",
        "rivedere",
        "rivelare",
        "rivolgere",
        "rivoluzione",
        "roba",
        "romano",
        "rompere",
        "rosso",
        "russo",
        "sacrificio",
        "sacro",
        "sala",
        "salire",
        "saltare",
        "salutare",
        "salvare",
        "sangue",
        "sapere",
        "sbagliare",
        "scala",
        "scappare",
        "scegliere",
        "scena",
        "scendere",
        "scherzare",
        "scienza",
        "scomparire",
        "scopo",
        "scoppiare",
        "scoprire",
        "scorrere",
        "scrittore",
        "scrivere",
        "scuola",
        "scusare",
        "se",
        "secolo",
        "secondo",
        "sede",
        "sedere",
        "segnare",
        "segno",
        "segretario",
        "segreto",
        "seguire",
        "seguito",
        "sembrare",
        "semplice",
        "senso",
        "sentimento",
        "sentire",
        "senza",
        "sera",
        "sereno",
        "serie",
        "serio",
        "servire",
        "servizio",
        "settimana",
        "sforzo",
        "sguardo",
        "si",
        "sicurezza",
        "sicuro",
        "significare",
        "signora",
        "signore",
        "signorina",
        "silenzio",
        "simile",
        "sinistro",
        "sino",
        "sistema",
        "situazione",
        "smettere",
        "sociale",
        "società",
        "soffrire",
        "sognare",
        "sogno",
        "soldato",
        "sole",
        "solito",
        "solo",
        "soltanto",
        "soluzione",
        "sonno",
        "sopra",
        "soprattutto",
        "sorella",
        "sorgere",
        "sorprendere",
        "sorridere",
        "sorriso",
        "sostenere",
        "sottile",
        "sotto",
        "spalla",
        "spazio",
        "speciale",
        "specie",
        "spegnere",
        "speranza",
        "sperare",
        "spesa",
        "spesso",
        "spettacolo",
        "spiegare",
        "spingere",
        "spirito",
        "sposare",
        "stabilire",
        "staccare",
        "stagione",
        "stamattina",
        "stampa",
        "stanco",
        "stanza",
        "stare",
        "stasera",
        "stato",
        "stazione",
        "stella",
        "stesso",
        "storia",
        "storico",
        "strada",
        "straniero",
        "strano",
        "straordinario",
        "stringere",
        "strumento",
        "studiare",
        "studio",
        "stupido",
        "su",
        "subito",
        "succedere",
        "successo",
        "sud",
        "suo",
        "suonare",
        "superare",
        "superiore",
        "svegliare",
        "sviluppo",
        "svolgere",
        "sì",
        "tacere",
        "tagliare",
        "tale",
        "tanto",
        "tardi",
        "tavola",
        "tavolo",
        "teatro",
        "tecnico",
        "tedesco",
        "temere",
        "tempo",
        "tendere",
        "tenere",
        "tentare",
        "termine",
        "terreno",
        "territorio",
        "terzo",
        "testa",
        "tipo",
        "tirare",
        "titolo",
        "toccare",
        "togliere",
        "tono",
        "tornare",
        "tra",
        "tranquillo",
        "trarre",
        "trascinare",
        "trasformare",
        "trattare",
        "tratto",
        "treno",
        "triste",
        "troppo",
        "trovare",
        "tu",
        "tuo",
        "tuttavia",
        "tutto",
        "uccidere",
        "udire",
        "ufficiale",
        "ufficio",
        "uguale",
        "ultimo",
        "umano",
        "un",
        "unico",
        "unire",
        "università",
        "uno",
        "uomo",
        "usare",
        "uscire",
        "uso",
        "utile",
        "valere",
        "valle",
        "valore",
        "vario",
        "vasto",
        "vecchio",
        "vedere",
        "vendere",
        "venire",
        "vento",
        "veramente",
        "verde",
        "verità",
        "vero",
        "verso",
        "vestire",
        "vestito",
        "vi",
        "via",
        "viaggio",
        "vicino",
        "villa",
        "vincere",
        "vino",
        "visita",
        "viso",
        "vista",
        "vita",
        "vivere",
        "vivo",
        "voce",
        "voglia",
        "voi",
        "volare",
        "volere",
        "volgere",
        "volontà",
        "volta",
        "voltare",
        "volto",
        "vostro",
        "vuoto",
        "zia",
        "zio",
        "zitto",
        "zona",
    )

    parts_of_speech: Dict[str, tuple] = {
        "verb": (
            "abaliena",
            "abbaiano",
            "abbandonatevi",
            "abbaruffavano",
            "abbelisca",
            "abbicava",
            "abbisciammo",
            "abbonati",
            "abborriva",
            "abbraciava",
            "abbrividisco",
            "abbrumavi",
            "abbrustoleremo",
            "abburattavano",
            "abiliterete",
            "abondai",
            "accadrebbe",
            "accalorammo",
            "accanalarono",
            "accapezzato",
            "accappucciasti",
            "accartoccerà",
            "accastellinando",
            "accavalcia",
            "acceleravo",
            "accentreremo",
            "accerti",
            "acchiocciolerò",
            "acciarpando",
            "accingerebbero",
            "accivettassero",
            "accoccavate",
            "accomiatano",
            "acconciavamo",
            "accoppiandosi",
            "accoriamo",
            "accottimeremo",
            "accucciolato",
            "accusiamoci",
            "acquadernassero",
            "acqueterebbero",
            "acuisci",
            "addebbiasti",
            "addentravo",
            "addimostrante",
            "addizionammo",
            "addolciai",
            "addormentatevi",
            "adduco",
            "aderiremmo",
            "adiuverei",
            "adonterei",
            "adsorbiremmo",
            "adunghierei",
            "aerotrasportò",
            "affamammo",
            "affaticarsi",
            "afferrassero",
            "affidano",
            "affilare",
            "affisate",
            "affluiresti",
            "affonderebbero",
            "affranchiamoci",
            "affretto",
            "affusolasse",
            "aggangherante",
            "aggettiverai",
            "aggiogherò",
            "aggiunteranno",
            "aggradiscano",
            "aggraticciavano",
            "aggriccio",
            "aggrotto",
            "agguanterete",
            "agitavi",
            "aguneremo",
            "albeggiando",
            "alchimierete",
            "alesi",
            "alimentammo",
            "allarga",
            "alleggerirebbero",
            "alleniremo",
            "allettati",
            "allicciavo",
            "allocchiresti",
            "allucchettassi",
            "alluminiò",
            "alò",
            "alternarono",
            "ambiasse",
            "ammacchereste",
            "ammanicatevi",
            "ammansirete",
            "ammassavi",
            "ammazzeranno",
            "ammezza",
            "ammiserireste",
            "ammollavi",
            "ammorbiate",
            "ammorzasse",
            "ammuffisca",
            "ammutolisti",
            "amplio",
            "anatomizzammo",
            "andicappava",
            "angariavamo",
            "animato",
            "annebbierai",
            "annichilavi",
            "annoderemmo",
            "annuissi",
            "anodizzava",
            "anterghereste",
            "antivenire",
            "aontato",
            "appacificherà",
            "appanetterà",
            "apparo",
            "appelleranno",
            "appesisco",
            "appiastreresti",
            "appiccoliste",
            "appisolantesi",
            "appoppantesi",
            "appresentiate",
            "approderete",
            "approprierai",
            "appulcreranno",
            "aprite",
            "arcaizzato",
            "ardiate",
            "argomento",
            "armonizzò",
            "arraffiare",
            "arrapinato",
            "arremberemo",
            "arricciarsi",
            "arrisicheresti",
            "arrolavamo",
            "arrostente",
            "arroventerebbero",
            "arrugginite",
            "articolerete",
            "ascoltai",
            "aspetterò",
            "assaltassero",
            "assedieranno",
            "assembro",
            "asservito",
            "assicurino",
            "assimilarono",
            "assoggettiamoci",
            "assommarono",
            "assordiresti",
            "assurgeranno",
            "astrologassi",
            "attardammo",
            "attendo",
            "atterzato",
            "attivare",
            "attortigliare",
            "attrappivano",
            "attruppavamo",
            "auggiarono",
            "aureolerebbero",
            "autocandidantesi",
            "autofinanziamoci",
            "autonominerebbero",
            "autorizzo",
            "avallò",
            "aviotrasportavate",
            "avvantaggereste",
            "avverare",
            "avvicinandosi",
            "avvinazzino",
            "avvitavamo",
            "avvolgesse",
            "azzanneremmo",
            "azzittivamo",
            "bacchettai",
            "bagorderà",
            "ballo",
            "bamboleggeresti",
            "baraccheranno",
            "barbugliavano",
            "barrire",
            "bassavate",
            "batteva",
            "beccheggiare",
            "benavrei",
            "benmeritino",
            "biancheggerà",
            "bidonassi",
            "bilanciante",
            "biondeggiaste",
            "biseco",
            "bituminaste",
            "blinderebbero",
            "boccio",
            "bonderizzavi",
            "bordo",
            "bramassero",
            "braserebbero",
            "brillantino",
            "brogliavano",
            "brulicherei",
            "bucando",
            "bugnate",
            "burlerebbe",
            "butterino",
            "cachiamoci",
            "cagionammo",
            "calcereste",
            "caletterebbe",
            "calunnierebbero",
            "campeggiano",
            "cancellassi",
            "cannassimo",
            "canteremo",
            "capendosi",
            "capitolavate",
            "capotteremmo",
            "carambolino",
            "carbossilai",
            "carezzate",
            "carpionassero",
            "carteggiavano",
            "cassassero",
            "catalogherebbe",
            "catramiate",
            "cavalcano",
            "cazziate",
            "celiavo",
            "censisti",
            "centrasse",
            "cernerai",
            "cheratinizzavano",
            "chiarificato",
            "chiedevate",
            "chinò",
            "choccassero",
            "cianfruglieranno",
            "cicatrizzerete",
            "cilindrarono",
            "cingerei",
            "circoncidete",
            "circonfondevamo",
            "circuivo",
            "ciulando",
            "clamavate",
            "clicchereste",
            "coabitare",
            "coccolarsi",
            "cogestirono",
            "cointeressa",
            "colettavo",
            "collettivizzerai",
            "colloquiereste",
            "coloritevi",
            "coltreremo",
            "comicizzerete",
            "commercializzi",
            "commisurerei",
            "compartente",
            "compattante",
            "compiacciate",
            "complessero",
            "complotterò",
            "compreremo",
            "computeresti",
            "concedono",
            "concetterebbero",
            "conclamassi",
            "concretizzare",
            "condescendendo",
            "conducevamo",
            "confettammo",
            "confinarono",
            "conformarono",
            "congedino",
            "congloba",
            "conguagliò",
            "connumerino",
            "conseguirete",
            "consocia",
            "constante",
            "contabilizzammo",
            "conteggiai",
            "contese",
            "contorcono",
            "contradissi",
            "contrarierò",
            "contravvenne",
            "controfirmasti",
            "controproverà",
            "controsterzino",
            "convenzionato",
            "convito",
            "coobavi",
            "copierà",
            "corazzi",
            "cornificarono",
            "corresponsabilizzerete",
            "corrucceremo",
            "cortocircuitarono",
            "cospiravi",
            "costicchiereste",
            "costudisco",
            "cracca",
            "crepitammo",
            "criptaste",
            "crivellava",
            "crollati",
            "crucciamoci",
            "culminate",
            "curvava",
            "dannato",
            "dattiloscritto",
            "debellate",
            "decaffeinizzerebbe",
            "decapò",
            "decellerate",
            "decideva",
            "declassificammo",
            "decompartimentate",
            "decongelavamo",
            "decorreva",
            "decriminalizziamo",
            "deducano",
            "deferirebbero",
            "defiscalizzavamo",
            "defluissero",
            "defosforò",
            "deglobalizzate",
            "deidrogenavamo",
            "delegifichiamo",
            "deliziamoci",
            "demanializzassero",
            "demilitarizzeranno",
            "demolivi",
            "demotivantesi",
            "denigrassimo",
            "denuclearizzerei",
            "deossigenerei",
            "deperivi",
            "depoliticizzai",
            "depravassimo",
            "deprivavi",
            "deratizzerei",
            "deresponsabilizzino",
            "desalaste",
            "deselezionavo",
            "desio",
            "desossidaste",
            "destatalizziamo",
            "destruggerebbe",
            "deterioreremo",
            "detronizzasti",
            "deventerei",
            "dia",
            "dialogizzavamo",
            "dieseranno",
            "differissero",
            "digitalizzavate",
            "digrigniate",
            "dilatantesi",
            "diligemmo",
            "dimagrirò",
            "dimetterete",
            "dimungessimo",
            "dipartissi",
            "diramate",
            "dirompente",
            "disaccentasse",
            "disacidiresti",
            "disamavano",
            "disappannavamo",
            "disarticolerete",
            "disattesi",
            "discaddero",
            "discernessero",
            "discioglievate",
            "discomporremo",
            "disconverresti",
            "discrediti",
            "disdegnassero",
            "disegnerebbe",
            "disgeleremmo",
            "disimballassi",
            "disincentivate",
            "disinformeranno",
            "disinnestavo",
            "disintendevi",
            "disloceresti",
            "disorganizzerò",
            "dispaiono",
            "disperdete",
            "disponente",
            "disqualificammo",
            "dissanguati",
            "dissentirò",
            "disseteresti",
            "dissodi",
            "distacchiate",
            "distolgano",
            "distringeresti",
            "disuniamoci",
            "disvolente",
            "divampate",
            "diversificheremmo",
            "divinerebbero",
            "documentavano",
            "domammo",
            "dondolava",
            "dormivi",
            "drappeggerà",
            "dubitò",
            "durerai",
            "eccettuato",
            "editate",
            "efficientasti",
            "eguaglierebbe",
            "elementarizzare",
            "elettrolizzavano",
            "elogiammo",
            "emanavi",
            "emettereste",
            "emungete",
            "entreresti",
            "epuriate",
            "equivalente",
            "ereditassimo",
            "eroicizzavo",
            "erutterà",
            "esaminavo",
            "esciresti",
            "escotete",
            "esento",
            "esigi",
            "esondò",
            "espatria",
            "espiavano",
            "esplorerò",
            "espungevate",
            "esterificherai",
            "estinguevo",
            "estraniaste",
            "estubano",
            "eterizzate",
            "euforizzeranno",
            "evidenziai",
            "evoluimmo",
            "fagocitavo",
            "falsifichiate",
            "farneticheremo",
            "fatturerebbero",
            "feda",
            "feltrò",
            "ferriamo",
            "fiacco",
            "ficcasti",
            "figliate",
            "filosofeggiò",
            "finlandizzavo",
            "fioretterei",
            "fischiettassero",
            "flambasti",
            "flocculerai",
            "fluorizzò",
            "fognassimo",
            "fondantesi",
            "forbissimo",
            "formavano",
            "fortificheranno",
            "fosforilo",
            "fracasserei",
            "frammischiava",
            "frappammo",
            "fraternizzato",
            "freme",
            "friggerebbero",
            "frodavi",
            "frullerebbe",
            "fucinai",
            "fumeggiamo",
            "fuorviasse",
            "gabellerai",
            "gambizza",
            "garrire",
            "gatteggiassimo",
            "gemeva",
            "gentrifico",
            "gessassero",
            "ghettizzassimo",
            "gibollerai",
            "giocheremmo",
            "gioverebbe",
            "girovagherà",
            "giuracchiavamo",
            "glassato",
            "glosserebbero",
            "gommiate",
            "governassero",
            "gradisti",
            "grafitante",
            "granulano",
            "grattugeresti",
            "gridavi",
            "gronderesti",
            "gualca",
            "guastiamoci",
            "gustante",
            "ideaste",
            "idrogenavamo",
            "illanguidisca",
            "imbaldanzirai",
            "imbarbarentesi",
            "imbastivi",
            "imbestierete",
            "imbietto",
            "imborghesentesi",
            "imbozzimando",
            "imbreccereste",
            "imbronciatevi",
            "imbullettammo",
            "imitavamo",
            "immergerà",
            "immiseriva",
            "impacceremmo",
            "impallai",
            "impaniante",
            "imparentatevi",
            "impastocchio",
            "impazzino",
            "impelagantesi",
            "imperiamo",
            "imperverserò",
            "impiastrò",
            "impiegherete",
            "impillaccheriamo",
            "implementavamo",
            "impoltroniscono",
            "importavo",
            "imprecasti",
            "impreziosirebbe",
            "improvviserei",
            "imputridissero",
            "inacidissi",
            "inalveerei",
            "inaridisti",
            "incadaveriste",
            "incamererò",
            "incannerai",
            "incappottavi",
            "incaricate",
            "incartate",
            "incastellerebbe",
            "incaveremmo",
            "incendieresti",
            "inceriamo",
            "inchiederai",
            "incideremmo",
            "incivilirai",
            "incoiavo",
            "incomincia",
            "incornicerete",
            "incresceresti",
            "incrostano",
            "inculchiate",
            "incuriosiscono",
            "indemaniavano",
            "indirebbero",
            "individueranno",
            "indovinerete",
            "industrializzerete",
            "infanatichisca",
            "infeltrirei",
            "infeudante",
            "infibulasse",
            "infilzato",
            "infiochisci",
            "inflazionasti",
            "infoderavi",
            "informavi",
            "infradiciò",
            "infrango",
            "infronzolava",
            "ingannate",
            "ingeneriamoci",
            "ingialliranno",
            "inglobano",
            "ingolosiate",
            "ingranando",
            "ingraziarsi",
            "inguaiassero",
            "iniettato",
            "innacquo",
            "innervosì",
            "innocuizziamo",
            "inorpellerete",
            "insabbierebbero",
            "insanguinò",
            "insedi",
            "inseristi",
            "insolentivi",
            "insozzo",
            "instilleremmo",
            "insulterete",
            "intarliamoci",
            "intelammo",
            "intensificheresti",
            "intercettano",
            "intercorrendo",
            "interfoliante",
            "intermezzerebbero",
            "interpenetrò",
            "interrompe",
            "intessevamo",
            "intingereste",
            "intonavamo",
            "intortavate",
            "intrappolerai",
            "intravveniva",
            "intrinseco",
            "intrometteste",
            "intruglieranno",
            "inumava",
            "invasare",
            "inventerai",
            "investiate",
            "invigoriranno",
            "invocano",
            "inzaccherammo",
            "inzuccherato",
            "ipostatizzante",
            "irraggi",
            "irrigidisti",
            "irrugginiste",
            "isomerizzassi",
            "istallarono",
            "istituzionalizzasse",
            "italianizzassero",
            "laccaste",
            "laicizzava",
            "lanciano",
            "largheggiate",
            "latitammo",
            "lavoracchiando",
            "legassimo",
            "legittimizzerei",
            "lesse",
            "liberesti",
            "limitavi",
            "liofilizzeremmo",
            "listerebbero",
            "localizzeremo",
            "lorderemo",
            "lucrano",
            "lussureggiarono",
            "macelleremmo",
            "maggiorò",
            "malignammo",
            "malversavi",
            "manganellante",
            "manimetti",
            "mansuefecero",
            "marcasse",
            "marginalizzereste",
            "marnai",
            "mascherassi",
            "massellarono",
            "masticheranno",
            "mattoneremmo",
            "medicalizzasti",
            "menassi",
            "menzionavate",
            "meridionalizzassi",
            "mesci",
            "mestruavi",
            "metamorfoserete",
            "miagolò",
            "migrasse",
            "mimeografiate",
            "mingeste",
            "miracoliamo",
            "missa",
            "mitizzano",
            "mobilizzava",
            "modernizzavamo",
            "molleggia",
            "monetarizzavo",
            "monopolizzano",
            "mordenzarono",
            "morsicava",
            "motorizzato",
            "muffisti",
            "multare",
            "muova",
            "mutizzando",
            "nasalizzate",
            "naufragavi",
            "nazionalizziate",
            "negozia",
            "nettavi",
            "nidificavate",
            "nitrì",
            "nomare",
            "notificatevi",
            "nudricavo",
            "nuotino",
            "obietta",
            "obnubilandosi",
            "occorrano",
            "odorizzammo",
            "offuscando",
            "oliando",
            "omaggiate",
            "omogenizzo",
            "onorarono",
            "oppignoravamo",
            "opsonizzerai",
            "ordiresti",
            "orgasmato",
            "orizzontate",
            "orpellate",
            "oscillasse",
            "osservano",
            "ossitonizzeresti",
            "ostruissimo",
            "ottonando",
            "ovariectomizzarono",
            "ovviavi",
            "pacifichino",
            "paginaste",
            "palettizzerà",
            "palpiteremmo",
            "paracadutiate",
            "parallelizzante",
            "parcheggiai",
            "parlamentavate",
            "parteggiammo",
            "parzializzereste",
            "passivi",
            "patinando",
            "pattuisse",
            "pazzierò",
            "peggiorate",
            "penderai",
            "pensò",
            "percolarono",
            "perdurerà",
            "performate",
            "permarrei",
            "perpetuerò",
            "persistei",
            "pervademmo",
            "petrarcheggerebbero",
            "piagnucolare",
            "piantonammo",
            "picchettaste",
            "pieghetterà",
            "pignorerà",
            "pinzino",
            "piroettino",
            "pitturaste",
            "planavi",
            "plissettiamo",
            "polemizza",
            "pomicerebbe",
            "popolarizzerai",
            "portende",
            "posizionerei",
            "posticipiate",
            "potettero",
            "preannunzieremo",
            "precingere",
            "preconfezionammo",
            "predefinite",
            "predireste",
            "prefatto",
            "preformarono",
            "preluderei",
            "premise",
            "prenotavate",
            "preponevo",
            "preregolereste",
            "prescrivo",
            "preservassimo",
            "prestarsi",
            "pretrattavamo",
            "preverremo",
            "privatizzerei",
            "procrastinarono",
            "proferire",
            "profilatevi",
            "prognosticheremmo",
            "proletarizzeresti",
            "promettevano",
            "pronunzieremmo",
            "propinano",
            "prorompente",
            "prospettassimo",
            "proteggente",
            "protrudono",
            "provoco",
            "pubblicasse",
            "pullulavamo",
            "punteggiò",
            "purificate",
            "quadravano",
            "quantificherai",
            "quietanzeresti",
            "rabboccante",
            "raccapezzare",
            "racchiuderemmo",
            "raccorcirebbero",
            "radazzavate",
            "radduceva",
            "radioassistette",
            "radiomarcai",
            "raffigurai",
            "raffrenò",
            "raggirassi",
            "raggranellassero",
            "ragguagliare",
            "ramate",
            "rammemorava",
            "rampicassero",
            "randomizzerebbe",
            "rapineremmo",
            "rapporteresti",
            "raschiettammo",
            "rassetterà",
            "rastrellato",
            "rattizzerebbe",
            "rauneremmo",
            "ravviserei",
            "razionerai",
            "recapiteranno",
            "recidivò",
            "reclude",
            "reddere",
            "refertavi",
            "refuti",
            "registrai",
            "regredivi",
            "reimpasta",
            "reincaricava",
            "reingaggiare",
            "reinseristi",
            "reinventeremmo",
            "remassi",
            "rendesti",
            "reputerebbero",
            "residuiate",
            "responde",
            "restringevamo",
            "retribuivi",
            "revisionassimo",
            "riabbracciasse",
            "riaccettai",
            "riaccostassimo",
            "riaddestravi",
            "riaffioravate",
            "riaggravavate",
            "riallineavano",
            "riammodernate",
            "riappacificasti",
            "riapplicavi",
            "riardeste",
            "riasfalterete",
            "riassettare",
            "riassunsi",
            "riattraversare",
            "riavvincente",
            "ribaltando",
            "riberrebbero",
            "ricadente",
            "ricalibravi",
            "ricapitalizzavi",
            "ricatterete",
            "ricevente",
            "riclassificarono",
            "ricolorarsi",
            "ricomparirebbe",
            "ricomponga",
            "riconciliatevi",
            "riconfondesse",
            "riconquistasti",
            "ricontattasse",
            "riconvertano",
            "ricordare",
            "ricostringano",
            "ricresciamo",
            "ridacchiamo",
            "ridestando",
            "ridimensioniamoci",
            "ridisegni",
            "ridiventare",
            "ridorato",
            "rieducavano",
            "riepilogherai",
            "rieserciterei",
            "riesumo",
            "rifenderai",
            "rifiggemmo",
            "rifirmavo",
            "rifoderavi",
            "riformulaste",
            "rifugiarono",
            "rigermoglieremo",
            "rigiudicavano",
            "riguardati",
            "rilavorasti",
            "rimagliavate",
            "rimarchiando",
            "rimbaldanzireste",
            "rimbellii",
            "rimboscasti",
            "rimenavate",
            "rimiraste",
            "rimondavo",
            "rimotivo",
            "rimpatriando",
            "rimpiccolimmo",
            "rimproverandosi",
            "rinacqui",
            "rincappano",
            "rincentrasti",
            "rincitrullirono",
            "rincoraggiasti",
            "rinculcate",
            "rinfagottarono",
            "rinfoderano",
            "ringagliardendo",
            "ringorgammo",
            "rinnovantesi",
            "rinsaccato",
            "rinselvatichiresti",
            "rintenderò",
            "rintonacheresti",
            "rintuzzano",
            "rinvaserai",
            "rinvilisce",
            "rinzeppiamo",
            "riordinino",
            "riparametrizzante",
            "ripercotemmo",
            "ripianante",
            "ripigliassi",
            "riponesti",
            "ripossedei",
            "riprincipiammo",
            "riprometterei",
            "ripugnerà",
            "riquadreremo",
            "risalti",
            "riscappai",
            "risciacquandosi",
            "riscoppiamo",
            "risedere",
            "riseppellisca",
            "risistemavate",
            "risolveresti",
            "risospendevate",
            "rispecchierei",
            "rispinse",
            "rissò",
            "ristenderemo",
            "ristuccare",
            "risusciteranno",
            "ritareremmo",
            "riterse",
            "ritornerebbero",
            "ritrasformerete",
            "ritufferete",
            "rivaccinandosi",
            "rivelano",
            "riverniciare",
            "rivitalizzai",
            "rivoltavamo",
            "roborate",
            "romanticizzante",
            "ronfavano",
            "rotacizzerete",
            "rovinerete",
            "rullando",
            "russificavi",
            "saccarificherò",
            "sagginasse",
            "saldiate",
            "salmodiamo",
            "salutati",
            "sanguinavamo",
            "saprà",
            "satireggiavate",
            "sbaciucchieremo",
            "sballottano",
            "sbandierarono",
            "sbarcarono",
            "sbatacchiavi",
            "sbendasse",
            "sbianchisce",
            "sbirbavano",
            "sbocciassero",
            "sborrerete",
            "sbozzolammo",
            "sbraniamo",
            "sbrilluccicherò",
            "sbucceresti",
            "sbullonereste",
            "scafa",
            "scalcerai",
            "scalfisce",
            "scalpiterebbe",
            "scampanaste",
            "scandagliereste",
            "scannerizzarono",
            "scapigliai",
            "scappottate",
            "scarcererei",
            "scarmiglieresti",
            "scarrozzaste",
            "scartellarono",
            "scatenammo",
            "scavezzavamo",
            "scenderete",
            "scheggiarsi",
            "schernissimo",
            "schiantai",
            "schierandosi",
            "schiudemmo",
            "sciabolassi",
            "sciamanizzato",
            "scimmieggino",
            "sciolinare",
            "sciupaste",
            "scoccavate",
            "scolarizzerai",
            "scolorissero",
            "scommettevo",
            "scompenserebbero",
            "sconciato",
            "sconfondendo",
            "sconquassano",
            "scontorceresti",
            "scoperchierebbe",
            "scoraggiremo",
            "scoreggiò",
            "scorpori",
            "scorticherebbero",
            "scotennasti",
            "scoverete",
            "screpolo",
            "scritturate",
            "scrosterà",
            "sculetta",
            "scuso",
            "sdilinquisti",
            "sdrucciolava",
            "secreterà",
            "seghettassimo",
            "segretassi",
            "sembravo",
            "sensibilizziamo",
            "seppelliste",
            "serpeggiavate",
            "setaccino",
            "sfaccendaste",
            "sfaldò",
            "sfarineresti",
            "sfavoriva",
            "sferza",
            "sfiderai",
            "sfinirà",
            "sfocia",
            "sfolleranno",
            "sformino",
            "sfracella",
            "sfregheremmo",
            "sfrucugliammo",
            "sgamavi",
            "sgarbugliavano",
            "sghiacciavano",
            "sgomentiate",
            "sgorgammo",
            "sgrammaticavate",
            "sgraveranno",
            "sgropperò",
            "sguarniate",
            "shuntavo",
            "silenziavo",
            "simmetrizzai",
            "sindacalizzando",
            "sinterizzato",
            "situati",
            "slappolavate",
            "slinguerai",
            "smacca",
            "smaliziantesi",
            "smanettava",
            "smarrisci",
            "smemorassi",
            "smerletteranno",
            "smineremo",
            "smobilitiate",
            "smorbi",
            "smurino",
            "snelliste",
            "snodò",
            "soccombente",
            "sofferire",
            "soffriggano",
            "soggiacessimo",
            "solarizzerebbe",
            "solfiterei",
            "solleciteremmo",
            "solviate",
            "somministrarono",
            "sopiremmo",
            "sopporterai",
            "sopraeleverei",
            "soprapose",
            "soprastampare",
            "sopravvivessero",
            "sorbisce",
            "sorradevo",
            "sorveglierò",
            "sostantivando",
            "sostituivate",
            "sottoalimentasse",
            "sottolineavi",
            "sottorappresenterai",
            "sottoutilizzo",
            "sovracapitalizzano",
            "sovraffollasti",
            "sovrapponiamoci",
            "sovrasterzai",
            "sovrintendere",
            "spacciando",
            "spalca",
            "spampinerei",
            "spantanerete",
            "spargerebbe",
            "spartiva",
            "spaventerebbero",
            "spazzoleresti",
            "speculiamo",
            "spenderai",
            "sperarono",
            "speronereste",
            "spettegolassi",
            "spezzono",
            "spiattelleranno",
            "spicconerai",
            "spigassero",
            "spiluccava",
            "spirantizzò",
            "spodestavi",
            "spollonerete",
            "spomperò",
            "sporgerei",
            "spostai",
            "sprigionandosi",
            "spromettere",
            "spugnerai",
            "spupazzai",
            "squagliaste",
            "squilibravate",
            "srotolerei",
            "stabuleremo",
            "stagionammo",
            "stampigliammo",
            "stanziò",
            "stasino",
            "stazzonò",
            "stenderai",
            "sterilizzerà",
            "stigmatizzavi",
            "stimolereste",
            "stiracchieremmo",
            "stomacheremmo",
            "storicizzerò",
            "strabenedissero",
            "stracchiamo",
            "stralunarono",
            "straniassi",
            "strapiomberò",
            "strasformereste",
            "stravolge",
            "stretto",
            "striminzire",
            "striscerò",
            "stromberà",
            "stroppieresti",
            "strusciavate",
            "stuelliate",
            "stuteresti",
            "subdelega",
            "sublocassimo",
            "succedendo",
            "sucheremo",
            "suffondi",
            "suicideremo",
            "superiate",
            "supportate",
            "surriscaldavo",
            "sussisteste",
            "svaligiante",
            "svaporeremo",
            "svelereste",
            "sventasti",
            "svermineremmo",
            "svicolammo",
            "svilupperebbe",
            "sviscerassi",
            "svolgevano",
            "tabulate",
            "taciuto",
            "tallonarono",
            "tangeste",
            "tariffammo",
            "tartassano",
            "tatuato",
            "teflonerete",
            "telematizzai",
            "tematizzare",
            "temporeggiano",
            "tentarono",
            "terebrate",
            "terrificherà",
            "tesero",
            "tifa",
            "tipicizzava",
            "titolerei",
            "tombolerò",
            "tonsurassimo",
            "tornasti",
            "tosasti",
            "totalizzeranno",
            "traccheggiasti",
            "trafficherai",
            "traguarderemmo",
            "tramestasse",
            "trancerò",
            "transcriverebbero",
            "transiteremmo",
            "trapaniate",
            "trapungerebbe",
            "trascendere",
            "trasducemmo",
            "trasfuso",
            "trasmodai",
            "traspongo",
            "trasvolgevo",
            "travalichereste",
            "travisi",
            "trescaste",
            "trilleremo",
            "tripartì",
            "trituraste",
            "troneggiato",
            "trucchiamo",
            "tumuliate",
            "tutelai",
            "ubiquitinassero",
            "ufficializzando",
            "ulcerereste",
            "umanizza",
            "unente",
            "universaleggerebbero",
            "urinassi",
            "usciolereste",
            "usureranno",
            "vacilli",
            "vagillando",
            "valicherete",
            "vanerai",
            "vantiate",
            "vasectomizzò",
            "veicolai",
            "vellicato",
            "vendicchiassi",
            "ventagliò",
            "vergheggiavate",
            "verniciare",
            "vessavi",
            "vezzeggiarsi",
            "videochattino",
            "vidimassero",
            "vilificheranno",
            "vinifico",
            "virgoletteranno",
            "visualizzavano",
            "vivacchierete",
            "vocabolarizzando",
            "volantinasse",
            "volicchio",
            "volturiamo",
            "votai",
            "zaffano",
            "zampognavo",
            "zavorrino",
            "zinnasti",
            "zoccolerà",
            "zoomo",
            "zumato",
        ),
        "noun": (
            "casa",
            "macchina",
            "albero",
            "libro",
            "penna",
            "bicicletta",
            "telefono",
            "tavolo",
            "sedia",
            "cane",
            "gatto",
            "finestra",
            "porta",
            "lampada",
            "letto",
            "divano",
            "televisione",
            "computer",
            "schermo",
            "tastiera",
            "mouse",
            "quaderno",
            "zaino",
            "cuscino",
            "coperta",
            "armadio",
            "scarpa",
            "calza",
            "maglietta",
            "pantaloni",
            "giacca",
            "cappello",
            "orologio",
            "occhiali",
            "borsa",
            "portafoglio",
            "ombrello",
            "cintura",
            "chiavi",
            "orologio",
            "spazzolino",
            "dentifricio",
            "sapone",
            "shampoo",
            "asciugamano",
            "specchio",
            "pettine",
            "rasoio",
            "profumo",
            "crema",
            "saponetta",
            "spugna",
            "lavandino",
            "doccia",
            "vasca",
            "bidet",
            "toilette",
            "lavatrice",
            "asciugatrice",
            "frigorifero",
            "forno",
            "microonde",
            "fornelli",
            "cappa",
            "lavastoviglie",
            "tostapane",
            "frullatore",
            "bollitore",
            "caffettiera",
            "teiera",
            "padella",
            "pentola",
            "coltello",
            "forchetta",
            "cucchiaio",
            "cucchiaino",
            "piatto",
            "bicchiere",
            "tazza",
            "ciotola",
            "vassoio",
            "bottiglia",
            "barattolo",
            "scatola",
            "sacco",
            "borsa",
            "secchio",
            "sacco",
            "pattumiera",
            "scopa",
            "paletta",
            "mocio",
            "straccio",
            "panno",
            "aspirapolvere",
            "ferro",
            "spazzola",
            "mollette",
            "stendibiancheria",
            "ventilatore",
            "condizionatore",
            "caldaia",
            "termosifone",
            "stufa",
            "camino",
            "caminetto",
            "candele",
            "accendino",
            "fiammiferi",
            "carta",
            "penna",
            "matita",
            "gomma",
            "righello",
            "compasso",
            "temperamatite",
            "calcolatrice",
            "agenda",
            "notes",
            "post-it",
            "cartella",
            "cartellina",
            "fascicoli",
            "archivio",
            "scaffale",
            "libreria",
            "poltrona",
            "tappeto",
            "tenda",
            "persiana",
            "quadri",
            "cornice",
            "scultura",
            "vasi",
            "fiori",
            "pianta",
            "albero",
            "cespuglio",
            "erba",
            "piante",
            "terra",
            "sabbia",
            "ghiaia",
            "roccia",
            "pietra",
            "marmo",
            "granito",
            "mattoni",
            "cemento",
            "intonaco",
            "pittura",
            "vernice",
            "pennello",
            "rullo",
            "spatola",
            "cazzuola",
            "secchio",
            "trapano",
            "cacciavite",
            "martello",
            "pinze",
            "tenaglie",
            "chiave",
            "livella",
            "metro",
            "nastro",
            "colla",
            "chiodo",
            "vite",
            "bullone",
            "dado",
            "rondella",
            "tassello",
            "calcestruzzo",
            "intonaco",
            "gesso",
            "stucco",
            "cartongesso",
            "saldatrice",
            "trapano",
            "avvitatore",
            "seghetto",
            "sega",
            "taglierina",
            "forbici",
            "taglierino",
            "scalpello",
            "pialla",
            "raspa",
            "levigatrice",
            "piallatrice",
            "fresa",
            "tornio",
            "trapano",
            "morsa",
            "mola",
            "smerigliatrice",
            "compensato",
            "legno",
            "tavola",
            "asse",
            "trave",
            "palo",
            "paletto",
            "pilastro",
            "colonna",
            "architrave",
            "tetto",
            "grondaia",
            "canale",
            "pluviale",
            "scarico",
            "pozzetto",
            "tombino",
            "serbatoio",
            "cisterna",
            "pozzo",
            "pompa",
            "tubo",
            "rubinetto",
            "valvola",
            "serratura",
            "chiavistello",
            "cardine",
            "cerniera",
            "catena",
            "lucchetto",
            "cavo",
            "filo",
            "corda",
            "spago",
            "nastro",
            "fune",
            "catena",
            "carrello",
            "ruota",
            "pneumatico",
            "cerchio",
            "disco",
            "pastiglie",
            "freno",
            "pedale",
            "acceleratore",
            "frizione",
            "cambio",
            "marcia",
            "retromarcia",
            "sterzo",
            "volante",
            "clacson",
            "specchietto",
            "parabrezza",
            "finestrino",
            "portiera",
            "bagagliaio",
            "cofano",
            "paraurti",
            "fanale",
            "faro",
            "fendinebbia",
            "targa",
            "siluro",
            "scarico",
            "marmitta",
            "filtro",
            "radiatore",
            "ventola",
            "alternatore",
            "batteria",
            "accensione",
            "candele",
            "serbatoio",
            "benzina",
            "olio",
            "liquido",
            "refrigerante",
            "acqua",
            "tergicristalli",
            "lavafari",
            "sbrinatore",
            "riscaldamento",
            "ventilazione",
            "condizionamento",
            "aria",
            "cambio",
            "differenziale",
            "trasmissione",
            "albero",
            "cardano",
            "giunto",
            "semiasse",
            "gomma",
            "pneumatico",
            "cerchio",
            "camera d'aria",
            "valvola",
            "pompa",
            "compressore",
            "manometro",
            "cric",
            "paranco",
            "sollevatore",
            "martinetto",
            "chiave",
            "torcia",
            "lampadina",
            "faretto",
            "luci",
            "led",
            "lampada",
            "neon",
            "faro",
            "luci",
            "frecce",
            "indicatori",
            "segnalatori",
            "triangolo",
            "gilet",
            "cintura",
            "airbag",
            "seggiolino",
            "portabiciclette",
            "portapacchi",
            "catene da neve",
            "copricerchi",
            "tappetini",
            "coprisedili",
            "parasole",
            "cuscini",
            "bracciolo",
            "poggiatesta",
            "poggiapiedi",
            "volante",
            "pomello",
            "maniglia",
            "pulsante",
            "interruttore",
            "levetta",
            "pedaliera",
            "console",
            "cruscotto",
            "tachimetro",
            "contachilometri",
            "indicatore",
            "termometro",
            "manometro",
            "contagiri",
            "indicatore",
            "spie",
            "avvisatori",
            "sensori",
            "radar",
            "telecamera",
            "parcheggio",
            "navigatore",
            "autoradio",
            "stereo",
            "altoparlanti",
            "subwoofer",
            "antenna",
            "ricevitore",
            "trasmettitore",
            "microfono",
            "vivavoce",
            "bluetooth",
            "USB",
            "presa",
            "cavo",
            "adattatore",
            "cuffie",
            "auricolari",
            "caricabatterie",
            "supporto",
            "cruscotto",
            "parabrezza",
            "tergicristalli",
            "specchietti",
            "fendinebbia",
            "fari",
            "fanali",
            "luci",
            "indicatori",
            "stop",
            "paraurti",
            "parafanghi",
            "minigonne",
            "spoiler",
            "tettuccio",
            "tetto",
            "bagagliaio",
            "cofano motore",
            "griglia",
            "mascherina",
            "logo",
            "stemma",
            "serratura",
        ),
        "adverb": (
            "sempre",
            "mai",
            "forse",
            "ancora",
            "ora",
            "subito",
            "prima",
            "poi",
            "dopo",
            "tardi",
            "presto",
            "qui",
            "lì",
            "lontano",
            "vicino",
            "sopra",
            "sotto",
            "davanti",
            "dietro",
            "fuori",
            "dentro",
            "insieme",
            "separatamente",
            "lentamente",
            "velocemente",
            "pianamente",
            "fortemente",
            "debolmente",
            "esattamente",
            "precisamente",
            "più",
            "meno",
            "molto",
            "poco",
            "abbastanza",
            "quasi",
            "affatto",
            "completamente",
            "parzialmente",
            "totalmente",
            "esattamente",
            "circa",
            "approssimativamente",
            "particolarmente",
            "specialmente",
            "tipicamente",
            "principalmente",
            "assolutamente",
            "relativamente",
            "ovviamente",
            "naturalmente",
            "certamente",
            "probabilmente",
            "immediatamente",
            "attentamente",
            "silenziosamente",
            "rumorosamente",
            "gentilmente",
            "bruscamente",
            "duramente",
            "facilmente",
            "difficilmente",
            "pericolosamente",
            "sicuramente",
            "così",
            "diversamente",
            "ugualmente",
            "altrimenti",
            "ancora",
            "già",
            "appena",
            "finora",
            "spesso",
            "raramente",
            "regolarmente",
            "casualmente",
            "necessariamente",
            "sicuramente",
            "evidentemente",
            "involontariamente",
            "volontariamente",
            "innocentemente",
            "maliziosamente",
            "strategicamente",
            "tatticamente",
            "efficacemente",
            "inefficacemente",
            "positivamente",
            "negativamente",
            "legalmente",
            "illegalmente",
            "temporaneamente",
            "permanentemente",
            "sistematicamente",
            "sporadicamente",
            "abitualmente",
            "occasionalmente",
            "frequentemente",
            "regolarmente",
            "puntualmente",
        ),
        "adjective": (
            "bello",
            "grande",
            "piccolo",
            "alto",
            "basso",
            "vecchio",
            "giovane",
            "nuovo",
            "forte",
            "debole",
            "veloce",
            "lento",
            "caldo",
            "freddo",
            "luminoso",
            "scuro",
            "ricco",
            "povero",
            "facile",
            "difficile",
            "pulito",
            "sporco",
            "felice",
            "triste",
            "intelligente",
            "stupido",
            "coraggioso",
            "codardo",
            "dolce",
            "amaro",
            "silenzioso",
            "rumoroso",
            "liscio",
            "ruvido",
            "gentile",
            "scortese",
            "tranquillo",
            "nervoso",
            "amichevole",
            "ostile",
            "serio",
            "allegro",
            "giusto",
            "sbagliato",
            "vero",
            "falso",
            "ordinato",
            "disordinato",
            "umido",
            "secco",
            "rotondo",
            "quadrato",
            "magro",
            "grasso",
            "chiaro",
            "opaco",
            "corto",
            "lungo",
            "affamato",
            "sazio",
            "amaro",
            "salato",
            "gentile",
            "sincero",
            "generoso",
            "egoista",
            "laborioso",
            "pigro",
            "onesto",
            "disonesto",
            "prudente",
            "avventato",
            "sicuro",
            "pericoloso",
            "fresco",
            "stanco",
            "noioso",
            "interessante",
            "curioso",
            "tranquillo",
            "vivace",
            "antipatico",
            "simpatico",
            "gentile",
            "maleducato",
            "contento",
            "arrabbiato",
            "innamorato",
            "geloso",
            "spaventato",
            "tranquillo",
            "stressato",
            "soddisfatto",
            "insoddisfatto",
            "creativo",
            "noioso",
            "timido",
            "estroverso",
            "affettuoso",
            "freddo",
        ),
    }



from ..de import Provider as AddressProvider


class Provider(AddressProvider):
    city_formats = ("{{city_name}}",)

    city_with_postcode_formats = ("{{postcode}} {{city}}",)

    street_name_formats = (
        "{{first_name}}-{{last_name}}-{{street_suffix_long}}",
        "{{last_name}}{{street_suffix_short}}",
    )
    street_address_formats = ("{{street_name}} {{building_number}}",)
    address_formats = ("{{street_address}}\n{{postcode}} {{city}}",)

    building_number_formats = ("###", "##", "#", "#/#")

    street_suffixes_long = (
        "Gasse",
        "Platz",
        "Ring",
        "Straße",
        "Weg",
    )
    street_suffixes_short = (
        "gasse",
        "platz",
        "ring",
        "straße",
        "str.",
        "weg",
    )

    # https://en.wikipedia.org/wiki/List_of_postal_codes_in_Austria
    postcode_formats = (
        "1###",
        "2###",
        "3###",
        "4###",
        "5###",
        "6###",
        "7###",
        "8###",
        "9###",
    )

    # https://en.wikipedia.org/wiki/List_of_cities_and_towns_in_Austria
    cities = (
        "Allentsteig",
        "Altheim",
        "Althofen",
        "Amstetten",
        "Ansfelden",
        "Attnang-Puchheim",
        "Bad Aussee",
        "Bad Hall",
        "Bad Ischl",
        "Bad Leonfelden",
        "Bad Radkersburg",
        "Bad Sankt Leonhard im Lavanttal",
        "Bad Vöslau",
        "Baden",
        "Bärnbach",
        "Berndorf",
        "Bischofshofen",
        "Bleiburg",
        "Bludenz",
        "Braunau am Inn",
        "Bregenz",
        "Bruck an der Leitha",
        "Bruck an der Mur",
        "Deutsch-Wagram",
        "Deutschlandsberg",
        "Dornbirn",
        "Drosendorf-Zissersdorf 1",
        "Dürnstein",
        "Ebenfurth",
        "Ebreichsdorf",
        "Eferding",
        "Eggenburg",
        "Eisenerz",
        "Eisenstadt",
        "Enns",
        "Fehring",
        "Feldbach",
        "Feldkirch",
        "Feldkirchen",
        "Ferlach",
        "Fischamend",
        "Frauenkirchen",
        "Freistadt",
        "Friedberg",
        "Friesach",
        "Frohnleiten",
        "Fürstenfeld",
        "Gallneukirchen",
        "Gänserndorf",
        "Geras",
        "Gerasdorf bei Wien",
        "Gföhl",
        "Gleisdorf",
        "Gloggnitz",
        "Gmünd",
        "Gmünd in Kärnten",
        "Gmunden",
        "Graz",
        "Grein",
        "Grieskirchen",
        "Groß-Enzersdorf",
        "Groß-Gerungs",
        "Groß-Siegharts",
        "Güssing",
        "Haag",
        "Hainburg an der Donau",
        "Hainfeld",
        "Hall in Tirol",
        "Hallein",
        "Hardegg",
        "Hartberg",
        "Heidenreichstein",
        "Herzogenburg",
        "Imst",
        "Innsbruck",
        "Jennersdorf",
        "Judenburg",
        "Kapfenberg",
        "Kindberg",
        "Klagenfurt",
        "Klosterneuburg",
        "Knittelfeld",
        "Köflach",
        "Korneuburg",
        "Krems an der Donau",
        "Kufstein",
        "Laa an der Thaya",
        "Laakirchen",
        "Landeck",
        "Langenlois",
        "Leibnitz",
        "Leoben",
        "Lienz",
        "Liezen",
        "Lilienfeld",
        "Linz",
        "Litschau",
        "Maissau",
        "Mank",
        "Mannersdorf am Leithagebirge",
        "Marchegg",
        "Marchtrenk",
        "Mariazell",
        "Mattersburg",
        "Mattighofen",
        "Mautern an der Donau",
        "Melk",
        "Mistelbach an der Zaya",
        "Mödling",
        "Murau",
        "Mureck",
        "Mürzzuschlag",
        "Neulengbach",
        "Neumarkt am Wallersee",
        "Neunkirchen",
        "Neusiedl am See",
        "Oberndorf bei Salzburg",
        "Oberpullendorf",
        "Oberwart",
        "Oberwälz",
        "Perg",
        "Peuerbach",
        "Pinkafeld",
        "Pöchlarn",
        "Poysdorf",
        "Pregarten",
        "Pulkau",
        "Purbach am Neusiedler See",
        "Purkersdorf",
        "Raabs an der Thaya",
        "Radenthein",
        "Radstadt",
        "Rattenberg",
        "Retz",
        "Ried im Innkreis",
        "Rohrbach in Oberösterreich",
        "Rottenmann",
        "Rust",
        "Saalfelden am Steinernen Meer",
        "Salzburg",
        "Sankt Andrä im Lavanttal",
        "Sankt Johann im Pongau",
        "Sankt Pölten",
        "Sankt Valentin",
        "Sankt Veit an der Glan",
        "Schärding",
        "Scheibbs",
        "Schladming",
        "Schrattenthal",
        "Schrems",
        "Schwanenstadt",
        "Schwaz",
        "Schwechat",
        "Spittal an der Drau",
        "Stadtschlaining",
        "Steyr",
        "Steyregg",
        "Stockerau",
        "Straßburg",
        "Ternitz",
        "Traiskirchen",
        "Traismauer",
        "Traun",
        "Trieben",
        "Trofaiach",
        "Tulln an der Donau",
        "Villach",
        "Vils",
        "Vöcklabruck",
        "Voitsberg",
        "Völkermarkt",
        "Waidhofen an der Thaya",
        "Waidhofen an der Ybbs",
        "Weitra",
        "Weiz",
        "Wels",
        "Wien",
        "Wiener Neustadt",
        "Wieselburg",
        "Wilhelmsburg",
        "Wolfsberg",
        "Wolkersdorf",
        "Wörgl",
        "Ybbs an der Donau",
        "Zell am See",
        "Zeltweg",
        "Zistersdorf",
        "Zwettl",
    )

    # https://en.wikipedia.org/wiki/States_of_Austria
    states = (
        "Wien",
        "Steiermark",
        "Burgenland",
        "Tirol",
        "Niederösterreich",
        "Oberösterreich",
        "Salzburg",
        "Kärnten",
        "Vorarlberg",
    )

    municipality_key_formats = (
        "1####",
        "2####",
        "3####",
        "4####",
        "5####",
        "6####",
        "7####",
        "8####",
        "9####",
    )

    def street_suffix_short(self) -> str:
        return self.random_element(self.street_suffixes_short)

    def street_suffix_long(self) -> str:
        return self.random_element(self.street_suffixes_long)

    def city_name(self) -> str:
        return self.random_element(self.cities)

    def administrative_unit(self) -> str:
        return self.random_element(self.states)

    state = administrative_unit

    def city_with_postcode(self) -> str:
        pattern: str = self.random_element(self.city_with_postcode_formats)
        return self.generator.parse(pattern)



from .. import Provider as BarcodeProvider


class Provider(BarcodeProvider):
    """Implement barcode provider for ``es_ES`` locale.

    Sources:

    - https://gs1.org/standards/id-keys/company-prefix
    """

    local_prefixes = ((8, 4),)



import importlib
import inspect
import os

from pathlib import Path

from faker.config import AVAILABLE_LOCALES
from faker.config import PROVIDERS as STANDARD_PROVIDER_NAMES
from faker.providers import BaseProvider

if os.environ.get("READTHEDOCS", False):
    version = os.environ["READTHEDOCS_VERSION"]
    HOME = Path("/home/docs/checkouts/readthedocs.org/user_builds/faker/checkouts") / version
    DOCS_ROOT = HOME / "docs"
else:
    DOCS_ROOT = Path(__file__).resolve().parents[2] / "docs"

SECTION_ADORNMENTS = "#*=-~"

PROVIDER_AUTODOC_TEMPLATE = """
.. autoclass:: {provider_class}
   :members: {provider_methods}
   :undoc-members:
   :show-inheritance:

"""

BASE_PROVIDER_METHOD_NAMES = [
    name for name, method in inspect.getmembers(BaseProvider, inspect.isfunction) if not name.startswith("_")
]


def _get_provider_methods(provider_class):
    try:
        provider_module_name, obj_name = provider_class.rsplit(".", 1)
        provider_module = importlib.import_module(provider_module_name)
        provider = getattr(provider_module, obj_name, None)
    except (ModuleNotFoundError, AttributeError):
        return ""
    else:
        return ", ".join(
            [
                name
                for name, method in inspect.getmembers(provider, inspect.isfunction)
                if not name.startswith("_") and name not in BASE_PROVIDER_METHOD_NAMES
            ]
        )


def _get_localized_provider_info(locale):
    info = []
    for provider_name in STANDARD_PROVIDER_NAMES:
        try:
            locale_module_path = f"{provider_name}.{locale}"
            locale_module = importlib.import_module(locale_module_path)
            provider = getattr(locale_module, "Provider")
        except (ModuleNotFoundError, AttributeError):
            continue
        else:
            provider_class = f"{provider.__module__}.Provider"
            info.append((provider_class, provider_name))
    return info


def _write(fh, s):
    return fh.write(s.encode("utf-8"))


def _hide_edit_on_github(fh):
    _write(fh, ":github_url: hide\n\n")


def _write_title(fh, title, level=1):
    if not isinstance(level, int) or level < 1 or level > 5:
        raise ValueError("`level` must be an integer from 1 to 5")
    if level <= 2:
        _write(fh, SECTION_ADORNMENTS[level - 1] * len(title))
        _write(fh, "\n")
    _write(fh, f"{title}\n")
    _write(fh, SECTION_ADORNMENTS[level - 1] * len(title))
    _write(fh, "\n\n")


def _write_includes(fh):
    _write(fh, ".. include:: ../includes/substitutions.rst")
    _write(fh, "\n\n")


def _write_standard_provider_index():
    with (DOCS_ROOT / "providers.rst").open("wb") as fh:
        _hide_edit_on_github(fh)
        _write_title(fh, "Standard Providers")
        _write(fh, ".. toctree::\n")
        _write(fh, "   :maxdepth: 2\n\n")
        _write(fh, "   providers/baseprovider\n")
        for provider_name in STANDARD_PROVIDER_NAMES:
            _write(fh, f"   providers/{provider_name}\n")


def _write_base_provider_docs():
    (DOCS_ROOT / "providers").mkdir(parents=True, exist_ok=True)
    with (DOCS_ROOT / "providers" / "baseprovider.rst").open("wb") as fh:
        _hide_edit_on_github(fh)
        _write_title(fh, "``faker.providers``")
        _write_includes(fh)
        _write(
            fh,
            PROVIDER_AUTODOC_TEMPLATE.format(
                provider_class="faker.providers.BaseProvider",
                provider_methods=",".join(BASE_PROVIDER_METHOD_NAMES),
            ),
        )


def _write_standard_provider_docs():
    (DOCS_ROOT / "providers").mkdir(parents=True, exist_ok=True)
    for provider_name in STANDARD_PROVIDER_NAMES:
        with (DOCS_ROOT / "providers" / f"{provider_name}.rst").open("wb") as fh:
            provider_class = f"{provider_name}.Provider"
            provider_methods = _get_provider_methods(provider_class)
            _hide_edit_on_github(fh)
            _write_title(fh, f"``{provider_name}``")
            _write_includes(fh)
            _write(
                fh,
                PROVIDER_AUTODOC_TEMPLATE.format(
                    provider_class=provider_class,
                    provider_methods=provider_methods,
                ),
            )


def _write_localized_provider_index():
    with (DOCS_ROOT / "locales.rst").open("wb") as fh:
        _hide_edit_on_github(fh)
        _write_title(fh, "Localized Providers")
        _write(fh, ".. toctree::\n")
        _write(fh, "   :maxdepth: 2\n\n")
        for locale in AVAILABLE_LOCALES:
            _write(fh, f"   locales/{locale}\n")


def _write_localized_provider_docs():
    (DOCS_ROOT / "locales").mkdir(parents=True, exist_ok=True)
    for locale in AVAILABLE_LOCALES:
        info = _get_localized_provider_info(locale)
        with (DOCS_ROOT / "locales" / f"{locale}.rst").open("wb") as fh:
            _hide_edit_on_github(fh)
            _write_title(fh, f"Locale {locale}")
            _write_includes(fh)
            for provider_class, standard_provider_name in info:
                provider_methods = _get_provider_methods(provider_class)
                _write_title(fh, f"``{standard_provider_name}``", level=2)
                _write(
                    fh,
                    PROVIDER_AUTODOC_TEMPLATE.format(
                        provider_class=provider_class,
                        provider_methods=provider_methods,
                    ),
                )


def write_provider_docs():
    DOCS_ROOT.mkdir(parents=True, exist_ok=True)
    _write_standard_provider_index()
    _write_base_provider_docs()
    _write_standard_provider_docs()
    _write_localized_provider_index()
    _write_localized_provider_docs()



from collections import OrderedDict

from .. import Provider as PersonProvider


class Provider(PersonProvider):
    # https://en.wikipedia.org/wiki/Demographics_of_Estonia#Ethnic_groups
    # Main population groups in Estonia are Estonians and ethnic Russians:
    # About 70% of the population are Estonians and about 25% are Russians
    est_rat = 0.7
    rus_rat = 1.0 - est_rat
    formats = OrderedDict(
        [
            ("{{first_name_est}} {{last_name_est}}", est_rat),
            ("{{first_name_rus}} {{last_name_rus}}", rus_rat),
        ]
    )

    formats_male = OrderedDict(
        [
            ("{{first_name_male_est}} {{last_name_est}}", est_rat),
            ("{{first_name_male_rus}} {{last_name_rus}}", rus_rat),
        ]
    )

    formats_female = OrderedDict(
        [
            ("{{first_name_female_est}} {{last_name_est}}", est_rat),
            ("{{first_name_female_rus}} {{last_name_rus}}", rus_rat),
        ]
    )

    prefixes_neutral = ("doktor", "dr", "prof")
    prefixes_male = ("härra", "hr") + prefixes_neutral
    prefixes_female = ("proua", "pr") + prefixes_neutral
    prefixes = sorted(set(prefixes_male + prefixes_female))

    suffixes = ("PhD", "MSc", "BSc")

    # source: http://www.stat.ee/public/apps/nimed/TOP
    # TOP 50 male names in 2017 according to the Statistics Estonia
    first_names_male_est = (
        "Aivar",
        "Aleksander",
        "Alexander",
        "Andres",
        "Andrus",
        "Ants",
        "Indrek",
        "Jaan",
        "Jaanus",
        "Jüri",
        "Kristjan",
        "Marek",
        "Margus",
        "Marko",
        "Martin",
        "Mati",
        "Meelis",
        "Mihkel",
        "Peeter",
        "Priit",
        "Raivo",
        "Rein",
        "Sander",
        "Siim",
        "Tarmo",
        "Tiit",
        "Toomas",
        "Tõnu",
        "Urmas",
        "Vello",
    )

    first_names_female_est = (
        "Aino",
        "Anna",
        "Anne",
        "Anneli",
        "Anu",
        "Diana",
        "Ene",
        "Eve",
        "Kadri",
        "Katrin",
        "Kristi",
        "Kristiina",
        "Kristina",
        "Laura",
        "Linda",
        "Maie",
        "Malle",
        "Mare",
        "Maria",
        "Marika",
        "Merike",
        "Niina",
        "Piret",
        "Reet",
        "Riina",
        "Sirje",
        "Tiina",
        "Tiiu",
        "Triin",
        "Ülle",
    )

    first_names_est = first_names_male_est + first_names_female_est

    first_names_male_rus = (
        "Aleksander",
        "Aleksandr",
        "Aleksei",
        "Alexander",
        "Andrei",
        "Artur",
        "Dmitri",
        "Igor",
        "Ivan",
        "Jevgeni",
        "Juri",
        "Maksim",
        "Mihhail",
        "Nikolai",
        "Oleg",
        "Pavel",
        "Roman",
        "Sergei",
        "Sergey",
        "Valeri",
        "Viktor",
        "Vladimir",
    )

    first_names_female_rus = (
        "Aleksandra",
        "Anna",
        "Diana",
        "Elena",
        "Galina",
        "Irina",
        "Jekaterina",
        "Jelena",
        "Julia",
        "Kristina",
        "Ljubov",
        "Ljudmila",
        "Maria",
        "Marina",
        "Nadežda",
        "Natalia",
        "Natalja",
        "Nina",
        "Olga",
        "Svetlana",
        "Tamara",
        "Tatiana",
        "Tatjana",
        "Valentina",
        "Viktoria",
    )

    first_names_rus = first_names_male_rus + first_names_female_rus

    first_names_male = sorted(set(first_names_male_est + first_names_male_rus))
    first_names_female = sorted(set(first_names_female_est + first_names_female_rus))
    first_names = sorted(set(first_names_male + first_names_female))

    # http://ekspress.delfi.ee/kuum/\
    # top-500-eesti-koige-levinumad-perekonnanimed?id=27677149
    last_names_est = (
        "Aas",
        "Aasa",
        "Aasmäe",
        "Aavik",
        "Abel",
        "Adamson",
        "Ader",
        "Alas",
        "Allas",
        "Allik",
        "Anderson",
        "Annus",
        "Anton",
        "Arro",
        "Aru",
        "Arula",
        "Aun",
        "Aus",
        "Eller",
        "Erik",
        "Erm",
        "Ernits",
        "Gross",
        "Hallik",
        "Hansen",
        "Hanson",
        "Hein",
        "Heinsalu",
        "Heinsoo",
        "Holm",
        "Hunt",
        "Härm",
        "Ilves",
        "Ivask",
        "Jaakson",
        "Jaanson",
        "Jaanus",
        "Jakobson",
        "Jalakas",
        "Johanson",
        "Juhanson",
        "Juhkam",
        "Jänes",
        "Järv",
        "Järve",
        "Jõe",
        "Jõesaar",
        "Jõgi",
        "Jürgens",
        "Jürgenson",
        "Jürisson",
        "Kaasik",
        "Kadak",
        "Kala",
        "Kalamees",
        "Kalda",
        "Kaljula",
        "Kaljurand",
        "Kaljuste",
        "Kaljuvee",
        "Kallas",
        "Kallaste",
        "Kalm",
        "Kalmus",
        "Kangro",
        "Kangur",
        "Kapp",
        "Karro",
        "Karu",
        "Kasak",
        "Kase",
        "Kasemaa",
        "Kasemets",
        "Kask",
        "Kass",
        "Kattai",
        "Kaur",
        "Kelder",
        "Kesküla",
        "Kiik",
        "Kiil",
        "Kiis",
        "Kiisk",
        "Kikas",
        "Kikkas",
        "Kilk",
        "Kink",
        "Kirs",
        "Kirsipuu",
        "Kirss",
        "Kivi",
        "Kivilo",
        "Kivimäe",
        "Kivistik",
        "Klaas",
        "Klein",
        "Koger",
        "Kohv",
        "Koit",
        "Koitla",
        "Kokk",
        "Kolk",
        "Kont",
        "Kool",
        "Koort",
        "Koppel",
        "Korol",
        "Kotkas",
        "Kotov",
        "Koval",
        "Kozlov",
        "Kriisa",
        "Kroon",
        "Krõlov",
        "Kudrjavtsev",
        "Kulikov",
        "Kuningas",
        "Kurg",
        "Kurm",
        "Kurvits",
        "Kutsar",
        "Kuus",
        "Kuuse",
        "Kuusik",
        "Kuusk",
        "Kärner",
        "Käsper",
        "Käär",
        "Käärik",
        "Kõiv",
        "Kütt",
        "Laan",
        "Laane",
        "Laanemets",
        "Laas",
        "Laht",
        "Laine",
        "Laks",
        "Lang",
        "Lass",
        "Laur",
        "Lauri",
        "Lehiste",
        "Leht",
        "Lehtla",
        "Lehtmets",
        "Leis",
        "Lember",
        "Lepik",
        "Lepp",
        "Leppik",
        "Liblik",
        "Liiv",
        "Liiva",
        "Liivak",
        "Liivamägi",
        "Lill",
        "Lillemets",
        "Lind",
        "Link",
        "Lipp",
        "Lokk",
        "Lomp",
        "Loorits",
        "Luht",
        "Luik",
        "Lukin",
        "Lukk",
        "Lumi",
        "Lumiste",
        "Luts",
        "Lätt",
        "Lääne",
        "Lääts",
        "Lõhmus",
        "Maasik",
        "Madisson",
        "Maidla",
        "Mandel",
        "Maripuu",
        "Mark",
        "Markus",
        "Martin",
        "Martinson",
        "Meier",
        "Meister",
        "Melnik",
        "Merila",
        "Mets",
        "Michelson",
        "Mikk",
        "Miller",
        "Mitt",
        "Moor",
        "Muru",
        "Must",
        "Mäe",
        "Mäeots",
        "Mäesalu",
        "Mägi",
        "Mänd",
        "Mändla",
        "Männik",
        "Männiste",
        "Mõttus",
        "Mölder",
        "Mürk",
        "Müür",
        "Müürsepp",
        "Niit",
        "Nurk",
        "Nurm",
        "Nuut",
        "Nõmm",
        "Nõmme",
        "Nõmmik",
        "Oja",
        "Ojala",
        "Ojaste",
        "Oks",
        "Olesk",
        "Oras",
        "Orav",
        "Org",
        "Ots",
        "Ott",
        "Paal",
        "Paap",
        "Paas",
        "Paju",
        "Pajula",
        "Palm",
        "Palu",
        "Parts",
        "Pent",
        "Peterson",
        "Pettai",
        "Pihelgas",
        "Pihlak",
        "Piho",
        "Piir",
        "Piirsalu",
        "Pikk",
        "Ploom",
        "Poom",
        "Post",
        "Pruul",
        "Pukk",
        "Pulk",
        "Puusepp",
        "Pärn",
        "Pärna",
        "Pärnpuu",
        "Pärtel",
        "Põder",
        "Põdra",
        "Põld",
        "Põldma",
        "Põldmaa",
        "Põllu",
        "Püvi",
        "Raadik",
        "Raag",
        "Raamat",
        "Raid",
        "Raidma",
        "Raja",
        "Rand",
        "Randmaa",
        "Randoja",
        "Raud",
        "Raudsepp",
        "Rebane",
        "Reimann",
        "Reinsalu",
        "Remmel",
        "Rohtla",
        "Roos",
        "Roosileht",
        "Roots",
        "Rosenberg",
        "Rosin",
        "Ruus",
        "Rätsep",
        "Rüütel",
        "Saar",
        "Saare",
        "Saks",
        "Salu",
        "Salumets",
        "Salumäe",
        "Sander",
        "Sarap",
        "Sarapuu",
        "Sarv",
        "Saul",
        "Schmidt",
        "Sepp",
        "Sibul",
        "Siim",
        "Sikk",
        "Sild",
        "Sillaots",
        "Sillaste",
        "Silm",
        "Simson",
        "Sirel",
        "Sisask",
        "Sokk",
        "Soo",
        "Soon",
        "Soosaar",
        "Soosalu",
        "Soots",
        "Suits",
        "Sulg",
        "Susi",
        "Sutt",
        "Suur",
        "Suvi",
        "Säde",
        "Sööt",
        "Taal",
        "Tali",
        "Talts",
        "Tamberg",
        "Tamm",
        "Tamme",
        "Tammik",
        "Teder",
        "Teearu",
        "Teesalu",
        "Teras",
        "Tiik",
        "Tiits",
        "Tilk",
        "Tomingas",
        "Tomson",
        "Toom",
        "Toome",
        "Tooming",
        "Toomsalu",
        "Toots",
        "Trei",
        "Treial",
        "Treier",
        "Truu",
        "Tuisk",
        "Tuul",
        "Tuulik",
        "Täht",
        "Tõnisson",
        "Uibo",
        "Unt",
        "Urb",
        "Uus",
        "Uustalu",
        "Vaher",
        "Vaht",
        "Vahter",
        "Vahtra",
        "Vain",
        "Vaino",
        "Valge",
        "Valk",
        "Vares",
        "Varik",
        "Veski",
        "Viik",
        "Viira",
        "Viks",
        "Vill",
        "Villemson",
        "Visnapuu",
        "Vähi",
        "Väli",
        "Võsu",
        "Õispuu",
        "Õun",
        "Õunapuu",
    )

    last_names_rus = (
        "Abramov",
        "Afanasjev",
        "Aleksandrov",
        "Alekseev",
        "Andreev",
        "Anissimov",
        "Antonov",
        "Baranov",
        "Beljajev",
        "Belov",
        "Bogdanov",
        "Bondarenko",
        "Borissov",
        "Bõstrov",
        "Danilov",
        "Davõdov",
        "Denissov",
        "Dmitriev",
        "Drozdov",
        "Egorov",
        "Fedorov",
        "Fedotov",
        "Filatov",
        "Filippov",
        "Fjodorov",
        "Fomin",
        "Frolov",
        "Gavrilov",
        "Gerassimov",
        "Golubev",
        "Gontšarov",
        "Gorbunov",
        "Grigoriev",
        "Gromov",
        "Gusev",
        "Ignatjev",
        "Iljin",
        "Ivanov",
        "Jakovlev",
        "Jefimov",
        "Jegorov",
        "Jermakov",
        "Jeršov",
        "Kalinin",
        "Karpov",
        "Karpov",
        "Kazakov",
        "Kirillov",
        "Kisseljov",
        "Klimov",
        "Kolesnik",
        "Komarov",
        "Kondratjev",
        "Konovalov",
        "Konstantinov",
        "Korol",
        "Kostin",
        "Kotov",
        "Koval",
        "Kozlov",
        "Kruglov",
        "Krõlov",
        "Kudrjavtsev",
        "Kulikov",
        "Kuzmin",
        "Kuznetsov",
        "Lebedev",
        "Loginov",
        "Lukin",
        "Makarov",
        "Maksimov",
        "Malõšev",
        "Maslov",
        "Matvejev",
        "Medvedev",
        "Melnik",
        "Mihhailov",
        "Miller",
        "Mironov",
        "Moroz",
        "Naumov",
        "Nazarov",
        "Nikiforov",
        "Nikitin",
        "Nikolaev",
        "Novikov",
        "Orlov",
        "Ossipov",
        "Panov",
        "Pavlov",
        "Petrov",
        "Poljakov",
        "Popov",
        "Romanov",
        "Rosenberg",
        "Rumjantsev",
        "Safronov",
        "Saveljev",
        "Semenov",
        "Sergejev",
        "Sidorov",
        "Smirnov",
        "Sobolev",
        "Sokolov",
        "Solovjov",
        "Sorokin",
        "Stepanov",
        "Suvorov",
        "Tarassov",
        "Tihhomirov",
        "Timofejev",
        "Titov",
        "Trofimov",
        "Tsvetkov",
        "Vasiliev",
        "Vinogradov",
        "Vlassov",
        "Volkov",
        "Vorobjov",
        "Voronin",
        "Zahharov",
        "Zaitsev",
        "Zujev",
        "Ševtšenko",
        "Štšerbakov",
        "Štšerbakov",
        "Žukov",
        "Žuravljov",
    )
    last_names = sorted(set(last_names_est + last_names_rus))

    def first_name_male_est(self) -> str:
        return self.random_element(self.first_names_male_est)

    def first_name_female_est(self) -> str:
        return self.random_element(self.first_names_female_est)

    def first_name_male_rus(self) -> str:
        return self.random_element(self.first_names_male_rus)

    def first_name_female_rus(self) -> str:
        return self.random_element(self.first_names_female_rus)

    def first_name_est(self) -> str:
        return self.random_element(self.first_names_est)

    def first_name_rus(self) -> str:
        return self.random_element(self.first_names_rus)

    def last_name_est(self) -> str:
        return self.random_element(self.last_names_est)

    def last_name_rus(self) -> str:
        return self.random_element(self.last_names_rus)



from collections import OrderedDict
from typing import Optional

from faker.providers.person.uk_UA import translit
from faker.typing import CardType, CreditCard

from .. import Provider as CreditCardProvider


class Provider(CreditCardProvider):
    """Implement credit card provider for ``uk_UA`` locale.
    https://blog.ipay.ua/uk/sekrety-bankovskix-kart-kak-identificirovat-bank-po-nomeru-karty/
    """

    prefix_visa = ["4"]
    prefix_mastercard = ["51", "52", "53", "54"]
    prefix_prostir = ["9"]
    prefix_maestro = ["6762"]

    credit_card_types = OrderedDict(
        (
            ("visa", CreditCard("Visa", prefix_visa, security_code="CVV2")),
            ("mastercard", CreditCard("Mastercard", prefix_mastercard, security_code="CVC2")),
            ("prostir", CreditCard("ПРОСТІР", prefix_prostir, security_code="CVC2")),
            ("maestro", CreditCard("Maestro", prefix_maestro, security_code="CVV")),
        )
    )

    def credit_card_full(self, card_type: Optional[CardType] = None) -> str:
        """Generate UA Credit Card:
        Supported card types 'visa', 'mastercard', 'prostir', 'maestro'

        :sample:
        :sample: card_type="prostir"
        :sample: card_type="mastercard"
        """
        card = self._credit_card_type(card_type)
        tpl = "{provider}\n{owner}\n{number} {expire_date}\n{security}: {security_nb}\n{issuer}"
        tpl = tpl.format(
            provider=card.name,
            owner=translit(
                self.generator.parse(
                    self.random_element(
                        [
                            "{{first_name_male}} {{last_name_male}}",
                            "{{first_name_female}} {{last_name_female}}",
                        ]
                    )
                )
            ),
            number=self.credit_card_number(card),
            expire_date=self.credit_card_expire(),
            security=card.security_code,
            security_nb=self.credit_card_security_code(card),
            issuer=self.generator.parse("{{bank}}"),
        )

        return self.generator.parse(tpl)



from collections import OrderedDict

from .. import Provider as ColorProvider


class Provider(ColorProvider):
    """Implement color provider for ``uk_UA`` locale.

    Sources:
    - https://uk.wikipedia.org/wiki/Список_кольорів
    """

    all_colors = OrderedDict(
        (
            ("Абрикосовий", "#FBCEB1"),
            ("Аквамариновий", "#7FFFD4"),
            ("Алізариновий червоний", "#E32636"),
            ("Амарантовий", "#E52B50"),
            ("Амарантово-рожевий", "#F19CBB"),
            ("Аметистовий", "#9966CC"),
            ("Андроїдний зелений", "#A4C639"),
            ("Арсеновий", "#3B444B"),
            ("Атомний мандаріновий", "#FF9966"),
            ("Багряний", "#FF2400"),
            ("Баклажановий", "#990066"),
            ("Барвінковий", "#CCCCFF"),
            ("Бежевий", "#F5F5DC"),
            ("Берлінська лазур", "#003153"),
            ("Блаватний", "#6495ED"),
            ("Блакитний", "#AFEEEE"),
            ("Блакитний Брандейса", "#0070FF"),
            ("Блакитно-зелений", "#00DDDD"),
            ("Блакитно-фіолетовий", "#8A2BE2"),
            ("Блідий рожево-ліловий", "#996666"),
            ("Блідо-брунатний", "#987654"),
            ("Блідо-волошковий", "#ABCDEF"),
            ("Блідо-карміновий", "#AF4035"),
            ("Блідо-каштановий", "#DDADAF"),
            ("Блідо-пурпуровий", "#F984E5"),
            ("Блідо-пісочний", "#DABDAB"),
            ("Блідо-рожевий", "#FADADD"),
            ("Болотний", "#ACB78E"),
            ("Бронзовий", "#CD7F32"),
            ("Брунатний", "#964B00"),
            ("Брунато-малиновий", "#800000"),
            ("Будяковий", "#D8BFD8"),
            ("Бузковий", "#C8A2C8"),
            ("Бургундський", "#900020"),
            ("Бурий", "#755A57"),
            ("Бурштиновий", "#FFBF00"),
            ("Білий", "#FFFFFF"),
            ("Білий навахо", "#FFDEAD"),
            ("Бірюзовий", "#30D5C8"),
            ("Бістр", "#3D2B1F"),
            ("Вода пляжа Бонді", "#0095B6"),
            ("Вохра", "#CC7722"),
            ("Відбірний жовтий", "#FFBA00"),
            ("Візантійський", "#702963"),
            ("Гарбуз", "#FF7518"),
            ("Гарячо-рожевий", "#FC0FC0"),
            ("Геліотроп", "#DF73FF"),
            ("Глибокий фіолетовий", "#423189"),
            ("Глицінія", "#C9A0DC"),
            ("Грушевий", "#D1E231"),
            ("Гумігут", "#E49B0F"),
            ("Гірчичний", "#FFDB58"),
            ("Дерева", "#79443B"),
            ("Джинсовий", "#1560BD"),
            ("Діамантово-рожевий", "#FF55A3"),
            ("Жовтий", "#FFFF00"),
            ("Жовто-зелений", "#ADFF2F"),
            ("Жовто-персиковий", "#FADFAD"),
            ("Захисний синій", "#1E90FF"),
            ("Зелена весна", "#00FF7F"),
            ("Зелена мʼята", "#98FF98"),
            ("Зелена сосна", "#01796F"),
            ("Зелене море", "#2E8B57"),
            ("Зелений", "#00FF00"),
            ("Зелений армійський", "#4B5320"),
            ("Зелений мох", "#ADDFAD"),
            ("Зелений папороть", "#4F7942"),
            ("Зелений чай", "#D0F0C0"),
            ("Зелено-сірий чай", "#CADABA"),
            ("Зеленувато-блакитний", "#008080"),
            ("Золотаво-березовий", "#DAA520"),
            ("Золотий", "#FFD700"),
            ("Золотисто-каштановий", "#6D351A"),
            ("Індиго", "#4B0082"),
            ("Іржавий", "#B7410E"),
            ("Кардинал (колір)", "#C41E3A"),
            ("Карміновий", "#960018"),
            ("Каштановий", "#CD5C5C"),
            ("Кобальтовий", "#0047AB"),
            ("Колір жовтого шкільного автобуса", "#FFD800"),
            ("Колір засмаги", "#D2B48C"),
            ("Колір морської піни", "#FFF5EE"),
            ("Колір морської хвилі", "#00FFFF"),
            ("Кораловий", "#FF7F50"),
            ("Королівський синій", "#4169E1"),
            ("Кремовий", "#FFFDD0"),
            ("Кукурудзяний", "#FBEC5D"),
            ("Кіновар", "#FF4D00"),
            ("Лавандний", "#E6E6FA"),
            ("Лазуровий", "#007BA7"),
            ("Лазурово-синій", "#2A52BE"),
            ("Лайм", "#CCFF00"),
            ("Латунний", "#B5A642"),
            ("Лимонний", "#FDE910"),
            ("Лимонно-кремовий", "#FFFACD"),
            ("Лляний", "#EEDC82"),
            ("Лляний", "#FAF0E6"),
            ("Лососевий", "#FF8C69"),
            ("Ліловий", "#DB7093"),
            ("Малахітовий", "#0BDA51"),
            ("Малиновий", "#DC143C"),
            ("Мандариновий", "#FFCC00"),
            ("Мисливський", "#004225"),
            ("Морквяний", "#ED9121"),
            ("Мідний", "#B87333"),
            ("Міжнародний помаранчевий", "#FF4F00"),
            ("Нефритовий", "#00A86B"),
            ("Ніжно-блакитний", "#E0FFFF"),
            ("Ніжно-оливковий", "#6B8E23"),
            ("Ніжно-рожевий", "#FB607F"),
            ("Оливковий", "#808000"),
            ("Опівнічно-синій", "#003366"),
            ("Орхідея", "#DA70D6"),
            ("Палена сіена", "#E97451"),
            ("Палений оранжевий", "#CC5500"),
            ("Панг", "#C7FCEC"),
            ("Паросток папаї", "#FFEFD5"),
            ("Пастельно-зелений", "#77DD77"),
            ("Пастельно-рожевий", "#FFD1DC"),
            ("Персиковий", "#FFE5B4"),
            ("Перський синій", "#6600FF"),
            ("Помаранчевий", "#FFA500"),
            ("Помаранчево-персиковий", "#FFCC99"),
            ("Помаранчево-рожевий", "#FF9966"),
            ("Пурпурний", "#FF00FF"),
            ("Пурпуровий", "#660099"),
            ("Пшеничний", "#F5DEB3"),
            ("Пісочний колір", "#F4A460"),
            ("Рожевий", "#FFC0CB"),
            ("Рожевий Маунтбеттена", "#997A8D"),
            ("Рожево-лавандний", "#FFF0F5"),
            ("Рожево-ліловий", "#993366"),
            ("Салатовий", "#7FFF00"),
            ("Сангрія", "#92000A"),
            ("Сапфіровий", "#082567"),
            ("Світло-синій", "#007DFF"),
            ("Сепія", "#704214"),
            ("Сиваво-зелений", "#ACE1AF"),
            ("Сигнально-помаранчевий", "#FF9900"),
            ("Синя пил", "#003399"),
            ("Синя сталь", "#4682B4"),
            ("Сині яйця малинівки", "#00CCCC"),
            ("Синій", "#0000FF"),
            ("Синій (RYB)", "#0247FE"),
            ("Синій (пігмент)", "#333399"),
            ("Синій ВПС", "#5D8AA8"),
            ("Синій Клейна", "#3A75C4"),
            ("Сливовий", "#660066"),
            ("Смарагдовий", "#50C878"),
            ("Спаржевий", "#7BA05B"),
            ("Срібний", "#C0C0C0"),
            ("Старе золото", "#CFB53B"),
            ("Сіра спаржа", "#465945"),
            ("Сірий", "#808080"),
            ("Сірий шифер", "#708090"),
            ("Темний весняно-зелений", "#177245"),
            ("Темний жовто-брунатний", "#918151"),
            ("Темний зелений чай", "#BADBAD"),
            ("Темний пастельно-зелений", "#03C03C"),
            ("Темний хакі", "#BDB76B"),
            ("Темний індиго", "#310062"),
            ("Темно-аспідний сірий", "#2F4F4F"),
            ("Темно-брунатний", "#654321"),
            ("Темно-бірюзовий", "#116062"),
            ("Темно-зелений", "#013220"),
            ("Темно-зелений хакі", "#78866B"),
            ("Темно-золотий", "#B8860B"),
            ("Темно-карміновий", "#560319"),
            ("Темно-каштановий", "#986960"),
            ("Темно-кораловий", "#CD5B45"),
            ("Темно-лазурний", "#08457E"),
            ("Темно-лососевий", "#E9967A"),
            ("Темно-мандариновий", "#FFA812"),
            ("Темно-оливковий", "#556832"),
            ("Темно-персиковий", "#FFDAB9"),
            ("Темно-рожевий", "#E75480"),
            ("Темно-синій", "#000080"),
            ("Ультрамариновий", "#120A8F"),
            ("Умбра", "#734A12"),
            ("Умбра палена", "#8A3324"),
            ("Фуксія", "#FF00FF"),
            ("Фіолетовий", "#8B00FF"),
            ("Фіолетово-баклажановий", "#991199"),
            ("Фіолетово-червоний", "#C71585"),
            ("Хакі", "#C3B091"),
            ("Цинамоновий", "#7B3F00"),
            ("Циннвальдит", "#EBC2AF"),
            ("Ціан (колір)", "#00FFFF"),
            ("Ціано-блакитний", "#F0F8FF"),
            ("Червоний", "#FF0000"),
            ("Червоно-буро-помаранчевий", "#CD5700"),
            ("Червоновато-брунатний", "#CC8899"),
            ("Чорний", "#000000"),
            ("Шафрановий", "#F4C430"),
            ("Шкіра буйвола", "#F0DC82"),
            ("Шоколадний", "#D2691E"),
            ("Яскраво-бурштиновий", "#FF7E00"),
            ("Яскраво-бірюзовий", "#08E8DE"),
            ("Яскраво-зелений", "#66FF00"),
            ("Яскраво-зелений", "#40826D"),
            ("Яскраво-рожевий", "#FF007F"),
            ("Яскраво-фіолетовий", "#CD00CD"),
            ("Ясно-брунатний", "#CD853F"),
            ("Ясно-вишневий", "#DE3163"),
            ("Ясно-лазуровий", "#007FFF"),
            ("Ясно-лазуровий (веб)", "#F0FFFF"),
        )
    )



from .. import Provider as BaseProvider


class Provider(BaseProvider):
    """
    A Faker provider for the Luxembourgish VAT IDs
    """

    vat_id_formats = ("LU########",)

    def vat_id(self) -> str:
        """
        http://ec.europa.eu/taxation_customs/vies/faq.html#item_11
        :return: a random Luxembourgish VAT ID
        """

        return self.bothify(self.random_element(self.vat_id_formats))



from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats_female = (
        "{{first_name_female}} {{last_name}}",
        "{{first_name_female}} {{last_name}}",
        "{{first_name_female}} {{last_name}}",
        "{{first_name_female}} {{last_name}}",
        "{{first_name_female}} {{last_name}}",
        "{{prefix_female}} {{first_name_female}} {{last_name}}",
    )

    formats_male = (
        "{{first_name_male}} {{last_name}}",
        "{{first_name_male}} {{last_name}}",
        "{{first_name_male}} {{last_name}}",
        "{{first_name_male}} {{last_name}}",
        "{{first_name_male}} {{last_name}}",
        "{{prefix_male}} {{first_name_male}} {{last_name}}",
    )

    formats = formats_male + formats_female

    """
    To a previous (undocumented?) list of female given names was added the 100
    most popular names in Brazil in 2014 and 2015 according to Exame magazine:
    * http://exame.abril.com.br/brasil/noticias/os-100-nomes-mais-comuns-no-brasil-em-2014
    * http://exame.abril.com.br/brasil/noticias/os-100-nomes-mais-comuns-no-brasil-em-2015
    Merged with this list from 2023
    * https://brasil.babycenter.com/a25034220/200-nomes-mais-populares-para-beb%C3%AAs-no-1%C2%BA-semestre-de-2023
    """
    first_names_female = (
        "Agatha",
        "Alana",
        "Alexia",
        "Alice",
        "Allana",
        "Alícia",
        "Amanda",
        "Ana",
        "Ana Beatriz",
        "Ana Carolina",
        "Ana Cecília",
        "Ana Clara",
        "Ana Julia",
        "Ana Júlia",
        "Ana Laura",
        "Ana Liz",
        "Ana Luiza",
        "Ana Lívia",
        "Ana Sophia",
        "Ana Vitória",
        "Anna Liz",
        "Antonella",
        "Aurora",
        "Ayla",
        "Aylla",
        "Beatriz",
        "Bella",
        "Bianca",
        "Brenda",
        "Bruna",
        "Bárbara",
        "Camila",
        "Carolina",
        "Caroline",
        "Catarina",
        "Cecilia",
        "Cecília",
        "Clara",
        "Clarice",
        "Daniela",
        "Eduarda",
        "Elisa",
        "Eloah",
        "Eloá",
        "Emanuella",
        "Emanuelly",
        "Emilly",
        "Ester",
        "Esther",
        "Evelyn",
        "Fernanda",
        "Gabriela",
        "Gabrielly",
        "Giovanna",
        "Hadassa",
        "Helena",
        "Hellena",
        "Heloisa",
        "Heloísa",
        "Isabel",
        "Isabela",
        "Isabella",
        "Isabelly",
        "Isadora",
        "Isis",
        "Jade",
        "Joana",
        "Julia",
        "Juliana",
        "Júlia",
        "Kamilly",
        "Lara",
        "Larissa",
        "Laura",
        "Lavínia",
        "Laís",
        "Letícia",
        "Liz",
        "Lorena",
        "Luana",
        "Luara",
        "Luiza",
        "Luna",
        "Lunna",
        "Luísa",
        "Lívia",
        "Maitê",
        "Manuela",
        "Manuella",
        "Marcela",
        "Maria",
        "Maria Alice",
        "Maria Cecília",
        "Maria Clara",
        "Maria Eduarda",
        "Maria Fernanda",
        "Maria Flor",
        "Maria Helena",
        "Maria Isis",
        "Maria Julia",
        "Maria Júlia",
        "Maria Laura",
        "Maria Liz",
        "Maria Luiza",
        "Maria Luísa",
        "Maria Sophia",
        "Maria Vitória",
        "Mariah",
        "Mariana",
        "Mariane",
        "Marina",
        "Maya",
        "Maysa",
        "Melina",
        "Melissa",
        "Milena",
        "Mirella",
        "Natália",
        "Nicole",
        "Nina",
        "Olivia",
        "Olívia",
        "Pietra",
        "Rafaela",
        "Raquel",
        "Rebeca",
        "Sabrina",
        "Sara",
        "Sarah",
        "Sofia",
        "Sophia",
        "Sophie",
        "Stella",
        "Stephany",
        "Valentina",
        "Vitória",
        "Yasmin",
        "Zoe",
        "Ágatha",
        "Ísis",
    )

    """
    To a previous (undocumented?) list of male given names was added the 100
    most popular names in Brazil in 2014 and 2015 according to this blog post:
    * http://exame.abril.com.br/brasil/noticias/os-100-nomes-mais-comuns-no-brasil-em-2014
    * http://exame.abril.com.br/brasil/noticias/os-100-nomes-mais-comuns-no-brasil-em-2015
    Merged with this list from 2023
    * https://brasil.babycenter.com/a25034220/200-nomes-mais-populares-para-beb%C3%AAs-no-1%C2%BA-semestre-de-2023
    """
    first_names_male = (
        "Alexandre",
        "André",
        "Anthony",
        "Anthony Gabriel",
        "Antony",
        "Antônio",
        "Apollo",
        "Arthur",
        "Arthur Gabriel",
        "Arthur Miguel",
        "Asafe",
        "Augusto",
        "Benicio",
        "Benjamim",
        "Benjamin",
        "Bento",
        "Benício",
        "Bernardo",
        "Brayan",
        "Breno",
        "Bruno",
        "Bryan",
        "Caio",
        "Caleb",
        "Calebe",
        "Carlos Eduardo",
        "Cauã",
        "Cauê",
        "Daniel",
        "Danilo",
        "Dante",
        "Davi",
        "Davi Lucas",
        "Davi Lucca",
        "Davi Luiz",
        "Davi Miguel",
        "Diego",
        "Diogo",
        "Dom",
        "Eduardo",
        "Emanuel",
        "Enrico",
        "Enzo",
        "Enzo Gabriel",
        "Erick",
        "Felipe",
        "Fernando",
        "Francisco",
        "Gabriel",
        "Gael",
        "Gael Henrique",
        "Guilherme",
        "Gustavo",
        "Gustavo Henrique",
        "Heitor",
        "Henrique",
        "Henry",
        "Henry Gabriel",
        "Ian",
        "Igor",
        "Isaac",
        "Isaque",
        "Joaquim",
        "Josué",
        "José",
        "José Miguel",
        "José Pedro",
        "João",
        "João Felipe",
        "João Gabriel",
        "João Guilherme",
        "João Lucas",
        "João Miguel",
        "João Pedro",
        "João Vitor",
        "Juan",
        "Kaique",
        "Kevin",
        "Leandro",
        "Leonardo",
        "Levi",
        "Liam",
        "Lorenzo",
        "Luan",
        "Lucas",
        "Lucas Gabriel",
        "Lucca",
        "Luigi",
        "Luiz Felipe",
        "Luiz Fernando",
        "Luiz Gustavo",
        "Luiz Henrique",
        "Luiz Miguel",
        "Luiz Otávio",
        "Léo",
        "Marcelo",
        "Marcos Vinicius",
        "Mateus",
        "Matheus",
        "Mathias",
        "Matteo",
        "Miguel",
        "Murilo",
        "Nathan",
        "Nicolas",
        "Noah",
        "Oliver",
        "Otto",
        "Otávio",
        "Paulo",
        "Pedro",
        "Pedro Henrique",
        "Pedro Lucas",
        "Pedro Miguel",
        "Pietro",
        "Rael",
        "Rafael",
        "Raul",
        "Ravi",
        "Ravi Lucca",
        "Ravy",
        "Renan",
        "Rhavi",
        "Rodrigo",
        "Ryan",
        "Samuel",
        "Thales",
        "Theo",
        "Theodoro",
        "Thiago",
        "Thomas",
        "Théo",
        "Valentim",
        "Vicente",
        "Vinicius",
        "Vinícius",
        "Vitor",
        "Vitor Gabriel",
        "Vitor Hugo",
        "Yago",
        "Yan",
        "Yuri",
    )

    first_names = first_names_male + first_names_female

    """
    To a previous (undocumented?) list of family names was added the 70
    most popular family names in Brazil according to this blog post:
    * http://nomeschiques.com/os-70-sobrenomes-mais-comuns-e-famosos-do-brasil/
    Merged with this list from 2023
    * https://nomescriativos.com.br/sobrenomes-mais-comuns/
    """
    last_names = (
        "Abreu",
        "Albuquerque",
        "Almeida",
        "Alves",
        "Andrade",
        "Aparecida",
        "Aragão",
        "Araújo",
        "Azevedo",
        "Barbosa",
        "Barros",
        "Borges",
        "Brito",
        "Caldeira",
        "Camargo",
        "Campos",
        "Cardoso",
        "Carvalho",
        "Casa Grande",
        "Cassiano",
        "Castro",
        "Cavalcante",
        "Cavalcanti",
        "Cirino",
        "Correia",
        "Costa",
        "Costela",
        "Cunha",
        "Câmara",
        "da Conceição",
        "da Costa",
        "da Cruz",
        "da Cunha",
        "da Luz",
        "da Mata",
        "da Mota",
        "da Paz",
        "da Rocha",
        "da Rosa",
        "das Neves",
        "Dias",
        "Duarte",
        "Farias",
        "Fernandes",
        "Ferreira",
        "Fogaça",
        "Fonseca",
        "Freitas",
        "Garcia",
        "Gomes",
        "Gonçalves",
        "Guerra",
        "Jesus",
        "Leão",
        "Lima",
        "Lopes",
        "Macedo",
        "Machado",
        "Marques",
        "Martins",
        "Melo",
        "Mendes",
        "Mendonça",
        "Monteiro",
        "Montenegro",
        "Moraes",
        "Moreira",
        "Moura",
        "Nascimento",
        "Nogueira",
        "Novaes",
        "Novais",
        "Nunes",
        "Oliveira",
        "Pacheco",
        "Pastor",
        "Peixoto",
        "Pereira",
        "Pimenta",
        "Pinto",
        "Pires",
        "Porto",
        "Ramos",
        "Rezende",
        "Ribeiro",
        "Rios",
        "Rocha",
        "Rodrigues",
        "Sales",
        "Sampaio",
        "Santos",
        "Silva",
        "Silveira",
        "Siqueira",
        "Sousa",
        "Souza",
        "Sá",
        "Teixeira",
        "Vargas",
        "Vasconcelos",
        "Viana",
        "Vieira",
    )

    prefixes_female = ("Srta.", "Sra.", "Dra.")
    prefixes_male = ("Sr.", "Dr.")
